$(document).ready(function () {
    loadStyleSheet('/modules/ubrr/css/ubrr.css');
    $messageBlock = $('#messageBlock');

    $(".getOrderStatus").click(function () {
        var twpg_order_id = parseInt($(this).attr('data-twpg_order_id'));
        var $button = $(this);

        ClearMessageBlock();

        diafan_ajax.init({
            data: {
                action: "get_order_status",
                module: "ubrr",
                twpg_order_id: twpg_order_id
            },
            success: function (response) {
                if (response.hasOwnProperty('success') && parseInt(response.success) == 1) {
                    $button.parent('td').append($('<span>' + response.order_status.label + '</span>'));
                }
                else {
                    $button.parent('td').append($('<span class="error">' + response.order_status.label + '</span>'));
                }
                $button.remove();

                if (response.hasOwnProperty('html')) {
                    ShowMessage(decodeHtml(response.html), false);
                }
            }
        });
    });

    $(".getOrderInfo").click(function () {
        var $button = $(this);
        var twpg_order_id = parseInt($(this).attr('data-twpg_order_id'));

        ClearMessageBlock();

        diafan_ajax.init({
            data: {
                action: "get_order_info",
                module: "ubrr",
                twpg_order_id: twpg_order_id
            },
            success: function (response) {
                if (response.hasOwnProperty('success') && parseInt(response.success) == 1) {
                    if (response.hasOwnProperty('html'))
                        ShowMessage(decodeHtml(response.html));
                }
                else {
                    $button.parent('td').append($('<span class="error">' + response.html + '</span>'));
                    $button.remove();
                }

            }
        });
    });

    function ClearMessageBlock() {
        $messageBlock.html('');
    }

    function ShowMessage(messageHTML, autoScroll) {
        $messageBlock.html(messageHTML);
        if (autoScroll != false) {
            var messageBlockTop = $messageBlock.offset().top;
            $('html,body').animate({scrollTop: messageBlockTop}, 500);
        }
    }

    function decodeHtml(str) {
        var map =
            {
                '&amp;': '&',
                '&lt;': '<',
                '&gt;': '>',
                '&quot;': '"',
                '&#039;': "'"
            };
        return str.replace(/&amp;|&lt;|&gt;|&quot;|&#039;/g, function (m) {
            return map[m];
        });
    }

    function loadStyleSheet(path, fn, scope) {
        var head = document.getElementsByTagName('head')[0], // reference to document.head for appending/ removing link nodes
            link = document.createElement('link');           // create the link node
        link.setAttribute('href', path);
        link.setAttribute('rel', 'stylesheet');
        link.setAttribute('type', 'text/css');

        var sheet, cssRules;
// get the correct properties to check for depending on the browser
        if ('sheet' in link) {
            sheet = 'sheet';
            cssRules = 'cssRules';
        } else {
            sheet = 'styleSheet';
            cssRules = 'rules';
        }

        var interval_id = setInterval(function () {                     // start checking whether the style sheet has successfully loaded
                try {
                    if (link[sheet] && link[sheet][cssRules].length) { // SUCCESS! our style sheet has loaded
                        clearInterval(interval_id);                      // clear the counters
                        clearTimeout(timeout_id);

                        if (typeof(fn) == 'function')
                            fn.call(scope || window, true, link);           // fire the callback with success == true
                    }
                } catch (e) {
                } finally {
                }
            }, 10), // how often to check if the stylesheet is loaded
            timeout_id = setTimeout(function () {       // start counting down till fail
                clearInterval(interval_id);             // clear the counters
                clearTimeout(timeout_id);
                head.removeChild(link);                // since the style sheet didn't load, remove the link node from the DOM
                if (typeof(fn) == 'function')
                    fn.call(scope || window, false, link);// fire the callback with success == false
            }, 15000);                                 // how long to wait before failing

        head.appendChild(link);  // insert the link node into the DOM and start loading the style sheet

        return link; // return the link node;
    }
});
