<?php
/**
 * Обработка POST-запросов
 *
 * @package    Diafan.CMS
 * @author     diafan.ru
 * @version    5.4
 * @license    http://cms.diafan.ru/license.html
 * @copyright  Copyright (c) 2003-2014 OOO «Диафан» (http://diafan.ru)
 */

if (!defined('DIAFAN')) {
    include realpath(dirname(__FILE__) . '/../_diafan_check.php');
}

class Ubrr_admin_action extends Action_admin
{
    /**
     * Вызывает обработку Ajax-запросов
     *
     * @return void
     */
    public function init()
    {
        if (!empty($_POST["action"])) {
            switch ($_POST["action"]) {
                case 'get_order_status':
                    $this->get_order_status();
                    break;
                case 'get_order_info':
                    $this->get_order_info();
                    break;
                case 'get_reconcile':
                    $this->get_reconcile();
                    break;
                case 'get_journal':
                    $this->get_journal();
                    break;
                case 'clear_log':
                    $this->clear_log();
                    break;
            }
        }
    }

    /**
     * Вызывает обработку Ajax-запросов
     *
     * @return void
     */
    public function get_order_status()
    {
        if (!empty($_POST['twpg_order_id'])) {
            $TWPG_OrderId = intval($_POST['twpg_order_id']);

            include_once realpath(dirname(__FILE__) . '/../_load_ubrr_classes.php');

            $diafanConnector = new \UBRIR\Diafan\DiafanConnector($this->diafan);
            $gatewayAdmin = new \UBRIR\Diafan\GatewayAdmin($diafanConnector);

            $responseData = $gatewayAdmin->GetOrderStatus($TWPG_OrderId);

            $orderStatusCode = $responseData->getFieldValue('OrderStatus');
            $orderStatus = \UBRIR\TypeEnums::GetLabel_OrderStatus($orderStatusCode);

            if ($responseData->isSuccess()) {
                $this->result['success'] = 1;
                $this->result['order_status'] = Array('code' => $orderStatusCode, 'label' => $orderStatus);
            } else {
                $this->result['success'] = 0;
                $this->result['order_status'] = Array('code' => $orderStatusCode, 'label' => $orderStatus);

                $this->result['html'] = 'В процессе обработки возникли ошибки';

                $shopId = $diafanConnector->GetShopId();
                $operation = $responseData->getFieldValue('Operation');
                if (strpos($operation, '!=') !== false && strpos($operation, $shopId) !== false) {
                    $this->result['html'] = 'Заказ был оформлен с другим номером ИМ';
                    $this->result['order_status']['label'] = 'Заказ был оформлен с другим номером ИМ';
                }
            }
        } else {
            $this->result["html"] = 'Не достаточно параметров для выполнения запроса';
        }
    }

    /**
     * Вызывает обработку Ajax-запросов
     *
     * @return void
     */
    public function get_order_info()
    {
        if (!empty($_POST['twpg_order_id'])) {
            $TWPG_OrderId = intval($_POST['twpg_order_id']);

            include_once realpath(dirname(__FILE__) . '/../_load_ubrr_classes.php');

            $diafanConnector = new \UBRIR\Diafan\DiafanConnector($this->diafan);
            $gatewayAdmin = new \UBRIR\Diafan\GatewayAdmin($diafanConnector);

            $responseData = $gatewayAdmin->GetOrderInfo($TWPG_OrderId);

            if ($responseData->isSuccess()) {
                $parsedResponse = $responseData->GetParsedResponse();
                $this->result['success'] = 1;
                $this->result['order_info'] = $parsedResponse['orderinfo'];//Array('code' => $orderStatusCode, 'label' => $orderStatus);
                $this->result['html'] = $this->diafan->_tpl->get('order_info', 'ubrr', $parsedResponse['orderinfo']);
            } else {
                $this->result['html'] = 'В процессе обработки возникли ошибки';
                $this->result['success'] = 0;

                $shopId = $diafanConnector->GetShopId();
                $operation = $responseData->getFieldValue('Operation');
                if (strpos($operation, '!=') !== false && strpos($operation, $shopId) !== false) {
                    $this->result['html'] = 'Заказ был оформлен с другим номером ИМ';
                }
            }
        } else {
            $this->result["html"] = 'Не достаточно параметров для выполнения запроса';
        }
    }


    /**
     * Вызывает обработку Ajax-запросов
     *
     * @return void
     */
    public function get_reconcile()
    {
        include_once realpath(dirname(__FILE__) . '/../_load_ubrr_classes.php');

        $diafanAdmin = new \UBRIR\Diafan\GatewayAdmin(new \UBRIR\Diafan\DiafanConnector($this->diafan));

        $responseData = $diafanAdmin->GetReconcile();
        if ($responseData->isSuccess()) {
            $parsedResponse = $responseData->GetParsedResponse();

            $this->result['reconcile'] = $parsedResponse['reconcile'];
            $this->result['html'] = $this->diafan->_tpl->get('reconcile', 'ubrr', Array('ajax' => 1, 'reconcile' => $parsedResponse['reconcile']));
        } else {
            $this->result['html'] = 'В процессе обработки возникли ошибки: ';
            $this->result['html'] .= '<br/>' . implode('<br/>', $responseData->GetErrors());
        }
    }

    public function get_journal()
    {
        include_once realpath(dirname(__FILE__) . '/../_load_ubrr_classes.php');

        $diafanAdmin = new \UBRIR\Diafan\GatewayAdmin(new \UBRIR\Diafan\DiafanConnector($this->diafan));

        $responseData = $diafanAdmin->GetJournal();
        if ($responseData->isSuccess()) {
            $parsedResponse = $responseData->GetParsedResponse();

            $this->result['journal'] = $parsedResponse['journal'];
            $this->result['html'] = $this->diafan->_tpl->get('journal', 'ubrr', Array('ajax' => 1, 'journal' => $parsedResponse['journal']));
        } else {
            $this->result['html'] = 'В процессе обработки возникли ошибки: ';
            $this->result['html'] .= '<br/>' . implode('<br/>', $responseData->GetErrors());
        }
    }

    public function clear_log()
    {
        include_once realpath(dirname(__FILE__) . '/../_load_ubrr_classes.php');
        $diafanAdmin = new \UBRIR\Diafan\GatewayAdmin(new \UBRIR\Diafan\DiafanConnector($this->diafan));
        $diafanAdmin->ClearLog();
    }
}