<?php
/**
 * Настройки модуля
 *
 * @package    Diafan.CMS
 * @author     diafan.ru
 * @version    5.4
 * @license    http://cms.diafan.ru/license.html
 * @copyright  Copyright (c) 2003-2014 OOO «Диафан» (http://diafan.ru)
 */

if (!defined('DIAFAN')) {
    include realpath(dirname(__FILE__) . '/../_diafan_check.php');
}

class Ubrr_admin_certificate_generate extends Frame_admin
{
    public $result;

    /**
     * Выводит контент модуля
     *
     * @return void
     */
    public function show()
    {
        $this->result = Array('message' => '');

        include_once realpath(dirname(__FILE__) . '/../_load_ubrr_classes.php');

        $connector = new \UBRIR\Diafan\DiafanConnector($this->diafan);
        $panel = new UBRIR\GatewayInteractionPanel();
        $panel->ConnectToCMS($connector);

        $arCountryList = \UBRIR\TypeEnums::GetCountryList();
        $this->result['arCountryList'] = $arCountryList;

        $arRuRegionsList = \UBRIR\TypeEnums::GetRuRegionList();
        $this->result['arRuRegionsList'] = $arRuRegionsList;

        $arRuCityList = \UBRIR\TypeEnums::GetRuCityList();
        $this->result['arRuCityList'] = $arRuCityList;

        $this->result['shopId'] = $connector->GetShopId();
        $this->result['newCertificatePassword'] = $connector->GetNewPrivateCertificatePassword();

        $this->result['resultText'] = '';

        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $this->result['RequestMethod'] = 'POST';
            $showForm = false;

            $merchant_id = $_POST['merchant_id'];
            $organization = $_POST['organization'];
            $from_email = $_POST['from_email'];
            $password = $_POST['password'];
            $country = $_POST['country'];
            $region = $_POST['region'];
            $city = $_POST['city'];
            $division = $_POST['division'];

            if (empty($organization)) {
                $this->result['resultText'] = 'Незаполненно поле "Организация"' . "\r\n";
                $showForm = true;
            }

            $merchantId = intval(trim($merchant_id));
            if (!($merchantId > 0)) {
                $valueErrors['merchant_id'] = 'Неверный формат номера ретейлера! (Он должен состоять исключительно из чисел!)';
                $this->result['resultText'] = '<div class="error">Неверный формат номера ретейлера! (Он должен состоять исключительно из чисел!)</div>';
                $showForm = true;
            }

            if (empty($from_email)) {
                $valueErrors['from_email'] = 'Неверный формат email ответственного лица!';
                $this->result['resultText'] = '<div class="error">Неверный формат email ответственного лица!</div>';
                $showForm = true;
            }

//Необходимости рисовать форму не возникло - значит генерируем сертификаты
            if (!$showForm) {
                if (!empty($organization)) {
                    $organization = \UBRIR\Helpers::Transliterate($organization);
                }

                if (empty($division))
                    $division = 'Sales';

                if (!empty($division)) {
                    $division = \UBRIR\Helpers::Transliterate($division);
                }

                if (!empty($country)) {
                    if (isset($arCountryList[$country]))
                        $country = $arCountryList[$country];
                    else
                        $country = \UBRIR\Helpers::Transliterate($country);
                }

                if (!empty($region)) {
                    if (isset($arRuRegionsList[$region]))
                        $region = $arRuRegionsList[$region];
                    else
                        $region = \UBRIR\Helpers::Transliterate($region);
                }

                if (!empty($city)) {
                    $city = \UBRIR\Helpers::Transliterate($city);
                }

                $certificateGenerator = $panel->GetCertificateGenerator();

                $responseData = $certificateGenerator->Generate($merchantId, $from_email, $password, $country, $region, $city, $organization, $division);
                $this->result['responseIsSuccess'] = $responseData->isSuccess();

                $arMessages = $responseData->GetMessages();

                if ($responseData->isSuccess()) {
                    $this->result['resultText'] = '<div class="success">' . $arMessages['success'][0] . '</div>';
                } else {
                    $this->result['resultText'] = '<div class="error">' . $arMessages['ERROR'][0] . '</div>';
                }
            }

            $this->result['merchant_id'] = $merchant_id;
            $this->result['organization'] = $organization;
            $this->result['from_email'] = $from_email;
            $this->result['password'] = $password;
            $this->result['country'] = $country;
            $this->result['region'] = $region;
            $this->result['city'] = $city;
            $this->result['division'] = $division;

        } else {
            $this->result['RequestMethod'] = 'GET';
            $showForm = true;
        }
        $this->result['showForm'] = $showForm;

        echo $this->diafan->_tpl->get('certificate_generate', 'ubrr', $this->result);
    }
}