<?php

namespace UBRIR\Diafan;

use \UBRIR\InterfaceConnectionConfig,
    \UBRIR\WorkMode;

class DiafanConnector implements InterfaceConnectionConfig
{
    const module_name = 'ubrr';

    private $diafanCore;
    private $sqlHelper;

    private $_shopId;
    private $_certificatePassword;
    private $_workMode;

    private $diafanModelParams;

    public $diafanPaginator;

    private $config = array(
        array('name' => 'ubrr_client_id', 'value' => ''),
        array('name' => 'ubrr_certificate_pass', 'value' => ''),
        array('name' => 'ubrr_test', 'value' => ''),
        array('name' => 'ubrr_new_certificate_password', 'value' => ''),
        array('name' => 'ubrr_certificate_create_date', 'value' => ''),
        Array('name' => 'ubrr_certificate_request_receivers', 'value' => 'eqv@ubrr.ru, alyushina@ubrr.ru')
    );

    public function __construct($diafanCore, $payId = false, $modelParams = null)
    {
        $this->_workMode = new WorkMode();
        $this->_workMode->SetNormal();

        $this->sqlHelper = new DiafanSQLHelper();

        $this->diafanCore = $diafanCore;

        if ($payId !== false) {
            $diafanOrderInfo = $this->diafanCore->_payment->check_pay($payId, 'ubrr');

            $this->_shopId = $diafanOrderInfo['params']['ubrr_client_id'];
            $this->_certificatePassword = $diafanOrderInfo['params']['ubrr_certificate_pass'];
            if ($diafanOrderInfo['params']["ubrr_test"] != 1) {
                $this->_workMode->SetTest();
            }
        } elseif ($modelParams === null) {
            $modelParams = $this->LoadModelParams();
        }

        if ($modelParams !== null) {
            $this->_shopId = $modelParams['ubrr_client_id'];
            $this->_certificatePassword = $modelParams['ubrr_certificate_pass'];

            if (intval($modelParams["ubrr_test"]) == 1) {
                $this->_workMode->SetTest();
            }
        }
    }

    private function LoadModelParams($force = false)
    {
        if ($this->diafanModelParams === null || $force) {
            foreach ($this->config as $param) {
                $paramValue = $this->diafanCore->configmodules($param['name'], "ubrr");
                $this->diafanModelParams[$param['name']] = $paramValue;
            }
        }

        return $this->diafanModelParams;
    }

    public function GetShopId()
    {
        return $this->_shopId;
    }

    public function SetShopId($shopId)
    {
        $this->_shopId = $shopId;

        $this->SetDiafanParam('ubrr_client_id', $shopId);
    }

    public function GetWorkMode()
    {
        return $this->_workMode;
    }

    public function SetPrivateCertificatePassword($newPassword)
    {
        $this->_certificatePassword = $newPassword;

        $this->SetDiafanParam('ubrr_certificate_pass', $newPassword);
    }

    public function GetPrivateCertificatePassword()
    {
        return $this->_certificatePassword;
    }

    public function GetOrderDataByUBRIROrderID($TWPG_OrderId)
    {
        $sql = $this->sqlHelper->GetOrderDataByUBRIROrderID($TWPG_OrderId);
        $rows = \DB::query_fetch_all($sql);

        if (count($rows) >= 1) {
            $row = $rows[0];

            $orderID = $row['diafan_order_id'];
            $payID = $row['diafan_pay_id'];
            $TWPG_OrderId = $row['twpg_order_id'];
            $SessionId = $row['twpg_session_id'];

            return array(
                'order_id' => $orderID,
                'payment_id' => $payID,
                'twpg_id' => $TWPG_OrderId,
                'session_id' => $SessionId
            );
        }
        return false;
    }

    public function GetOrderDataByShopOrderID($OrderId)
    {
        $sql = $this->sqlHelper->GetOrderDataByShopOrderID($OrderId);
        $rows = \DB::query_fetch_all($sql);

        if (count($rows) >= 1) {
            $row = $rows[0];

            $TWPG_OrderId = $row ['twpg_order_id'];
            $SessionId = $row ['twpg_session_id'];
            return array(
                'twpg_order_id' => $TWPG_OrderId,
                'twpg_session_id' => $SessionId
            );
        }
        return false;
    }

    public function SaveTWPGOrder($orderId, $TWPG_OrderId, $SessionId, $paymentId = false)
    {
        $sql = $this->sqlHelper->SaveTWPGOrder($orderId, $TWPG_OrderId, $SessionId, $paymentId);

        $dbResult = \DB::query($sql);
        return $dbResult;
    }

    public function GetOrdersList($pageNum = 1, $perPageCount = 10)
    {
        $sql = $this->sqlHelper->GetOrdersList();

        /*
         * 	public static function query_range_fetch_all($query)
	        {
        		$args = func_get_args();
                $count = array_pop($args); //nastr
		        $from = array_pop($args); //polog
         */
        $orders = \DB::query_fetch_all($sql); //\DB::query_range_fetch_all($sql, $this->diafanCore->_paginator->polog, $this->diafanCore->_paginator->nastr);
        $this->diafanPaginator = $this->diafanCore->_paginator->get();

        return $orders;
    }

    public function GetDefaultContinueLink()
    {
        $serverHost = $_SERVER['SERVER_NAME'];

        if (!empty($_SERVER['HTTPS'])) {
            $urlPrefix = 'http://' . $serverHost;
        } else {
            $urlPrefix = 'http://' . $serverHost;
        }

        return $urlPrefix;
    }


    public function UpdateCertificateCreateDate($creationDate = false)
    {
        if (!$creationDate) {
            $creationDate = date('d.m.Y', time());
        }

        $this->SetDiafanParam('ubrr_certificate_create_date', $creationDate);
    }

    public function GetCertificateCreateDate()
    {
        return $this->GetDiafanParam('ubrr_certificate_create_date');
    }

    public function SetNewPrivateCertificatePassword($newPrivatePassword = '')
    {
        $this->SetDiafanParam('ubrr_new_certificate_password', $newPrivatePassword);
    }

    public function GetNewPrivateCertificatePassword()
    {
        $newPrivatePassword = $this->GetDiafanParam('ubrr_new_certificate_password');

        return $newPrivatePassword;
    }

    public function GetBankReceiversEmailList()
    {
        $arReceivers = $this->GetDiafanParam('ubrr_certificate_request_receivers');

        if (!is_array($arReceivers) && (is_string($arReceivers) && !empty($arReceivers))) {
            $arReceivers = explode(',', $arReceivers);
        }

        return $arReceivers;
    }


    /*
     * Поскольку факир как обычно пьян идем в обход
     * Подсмотрено в \diafan\adm\includes\save.php
     * Потом подсмотрено в БД
     */
    private function SetDiafanParam($paramName, $paramValue)
    {
        //Убираем проблемные символ(ы)
        $cParamValue = false;
        $paramValue = str_replace("\n", '', $paramValue);

        $this->LoadModelParams();

        $getConfigIdSQL = $this->sqlHelper->GetConfigFormDB($paramName);
        $mysqliResult = \DB::query($getConfigIdSQL);
        $result = $mysqliResult->fetch_row();

        if (is_array($result)) {
            $cParamValue = $result[2];

            if ($cParamValue !== $paramValue) {
                $updateSQL = $this->sqlHelper->UpdateModuleConfigValue($paramName);
                \DB::query($updateSQL, $paramValue);
            }
        } else {
            $insertSQL = $this->sqlHelper->AddModuleConfigValue($paramName);
            \DB::query($insertSQL, $paramValue);
        }

        if ($cParamValue !== $paramValue) {
            $this->diafanModelParams[$paramName] = $paramValue;

            // Удаляет кэш конфигурации модулей
            $this->diafanCore->_cache->delete("configmodules", "site");
        }
    }

    private function GetDiafanParam($paramName)
    {
        $this->LoadModelParams();

        return $this->diafanModelParams[$paramName];
    }

    public function GetTWPGDataByPayId($payId)
    {
        $sql = $this->sqlHelper->GetTWPGDataByPayId($payId);
        $mysqliResult = \DB::query($sql);
        $row = $mysqliResult->fetch_row();

        if (is_array($row)) {
            $TWPG_OrderId = $row ['twpg_order_id'];
            $SessionId = $row ['twpg_session_id'];
            return array(
                'twpg_order_id' => $TWPG_OrderId,
                'twpg_session_id' => $SessionId
            );
        }
        return false;
    }
}