<?php
/**
 * Created by PhpStorm.
 * User: Alexander
 * Date: 31.01.2017
 * Time: 10:27
 */

namespace UBRIR;

use MongoDB\BSON\Type;

abstract class CMS_Payment
{
    const WorkMode_Test = 'TEST';
    const WorkMode_Normal = 'NORMAL';

    protected $workMode; //test / normal
    protected $logDir;
    protected $logFile;
    protected $useLogs;

    //XML Data
    protected $shopId;
    protected $certificatePassword;

    protected $orderId;
    protected $ubrrOrderId; //twpg
    protected $ubrrSessionId; //twpg
    protected $orderAmount; //нужно умножать на 100 (потому что в копейках)
    protected $paymentUrl;
    protected $paymentStatus;

    protected $approveUrl;
    protected $cancelUrl;
    protected $declineUrl;

    protected $uniLogin;
    protected $uniPass;

    protected $CACertificateFile;
    protected $publicCertificateFile;
    protected $privateCertificateFile;
    protected $privateCertificatePass;

    public function __construct()
    {
        $this->workMode = self::WorkMode_Test;

        $this->Log('[START]');
    }

    public function setNormalWorkMode()
    {
        $this->workMode = self::WorkMode_Normal;
    }

    public function HandleCallback()
    {
        if (!isset($_POST['xmlmsg'])) {
            $response = new DataContainer();
            $response->AddError('Неверный запрос сервера');
        }

        $XMLString = base64_decode($_POST['xmlmsg']);
        $xmlLines = explode("\n", $XMLString);

        //Проверяем что с XML все в порядке (по большому счету это нужно только как защита от прямых дерганий callback
        libxml_use_internal_errors(); //Подавляем вывод ошибок XML
        $demoXML = simplexml_load_string($XMLString);
        $xmlErrors = libxml_get_errors();
        if (count($xmlErrors) > 0) {
            $this->Log('Обнаружены ошибки в XML');
            foreach ($xmlErrors as $error) {
                $this->Log(self::FormatXMLError($error, $xmlLines));
            }

            $response = new DataContainer();
            $response->AddError('Обнаружены ошибки в XML');
        } else {
            $this->Log('Callback: Разбирем полученный XML');
            $this->Log($XMLString);

            $objXML = simplexml_load_string($XMLString);
            $arKeyValueXML = ServerConnector::XML2Array($XMLString);
            $response = new DataContainer();
            $response->setSuccess()->SaveXMLData($XMLString, $objXML, $arKeyValueXML);
        }

        return $response;
    }

    private function FormatXMLError($error, $xml)
    {
        $return = $xml[$error->line - 1] . "\n";
        $return .= str_repeat('-', $error->column) . "^\n";

        switch ($error->level) {
            case LIBXML_ERR_WARNING:
                $return .= "Warning $error->code: ";
                break;
            case LIBXML_ERR_ERROR:
                $return .= "Error $error->code: ";
                break;
            case LIBXML_ERR_FATAL:
                $return .= "Fatal Error $error->code: ";
                break;
        }

        $return .= trim($error->message) .
            "\n  Line: $error->line" .
            "\n  Column: $error->column";

        if ($error->file) {
            $return .= "\n  File: $error->file";
        }

        return "$return\n\n--------------------------------------------\n\n";
    }

    protected function Certificates_DefaultPrivateFiles()
    {
        $validPrivateFiles = Array();
        $validPrivateFiles[] = $this->ModuleRootDir . 'certs/user.key';
        $validPrivateFiles[] = $this->ModuleRootDir . 'certs/' . $this->shopId . '_private.key';
        $validPrivateFiles[] = $this->ModuleRootDir . 'certs/' . $this->shopId . '_private.pem';

        return $validPrivateFiles;
    }

    protected function Certificates_DefaultPublicFiles()
    {
        $validPublicFiles = Array();
        $validPublicFiles[] = $this->ModuleRootDir . 'certs/user.pem';
        $validPublicFiles[] = $this->ModuleRootDir . 'certs/' . $this->shopId . '.pem';

        return $validPublicFiles;
    }

    /**
     * Заполняем проверяем настройки сертификатов для общения с сервером
     */
    public function ServerConnectionConfig($shopId, $privatePassword, $publicCertificate = '', $privateCertificate = '', $CACertificate = '')
    {
        $this->shopId = $shopId;
        $this->privateCertificatePass = $privatePassword;

        //$certFile = $this->ConvertCertificateToPEM($certFile);
        //$certFile = $UBRR_ROOT . "certs/cert.pem";

        //Сертификат банка
        if (!empty($CACertificate)) {
            //Проверка существует ли переданных сертификат
            if (!file_exists($CACertificate)) {
                $CACertificate = false;
            }
        } else {
            //Поиск стандартного банковского сертификата
            $bankCAFile = 'bank';
            if ($this->workMode == self::WorkMode_Test) {
                $bankCAFile = 'bank_test';
            }

            $CACertificate = $this->ModuleRootDir . 'certs/' . $bankCAFile . '.pem';
            if (!file_exists($CACertificate)) {
                //Пробуем найти crt
                $CACertificate = $this->ModuleRootDir . 'certs/' . $bankCAFile . '.crt';
                if (!file_exists($CACertificate)) {
                    $CACertificate = false;
                }
            }
        }

        //Публичный сертификат
        if (!empty($publicCertificate)) {
            if (!file_exists($publicCertificate)) {
                $publicCertificate = false;
            }
        } else {
            //Поиск публичного сертификата в соответсвии с изначальными настройками
            $validPublicFiles = $this->Certificates_DefaultPublicFiles();

            $publicCertificate = false;
            foreach ($validPublicFiles as $publicCertFile)
                if (file_exists($publicCertFile)) {
                    $publicCertificate = $publicCertFile;
                    break;
                }
        }

        //Приватный сертификат
        if (!empty($privateCertificate)) {
            if (!file_exists($privateCertificate)) {
                $privateCertificate = false;
            }
        } else {
            //Поиск публичного сертификата в соответсвии с изначальными настройками

            $privateCertificate = false;
            $validPrivateFiles = $this->Certificates_DefaultPrivateFiles();
            foreach ($validPrivateFiles as $privateCertFile)
                if (file_exists($privateCertFile)) {
                    $privateCertificate = $privateCertFile;
                    break;
                }
        }

        $this->publicCertificateFile = $publicCertificate;
        $this->privateCertificateFile = $privateCertificate;
        $this->CACertificateFile = $CACertificate;
    }

    /**
     * Проверяем что все необходимые поля для подготовки оплаты переданы и можно формировать XML к отправке
     * @return mixed
     */
    public abstract function PrepareToPay();

    public abstract function CheckOrderStatus();

    public abstract function GetOrderInformation();

    private function ConvertTime($strTime)
    {
        //date
        $str = substr($strTime, 0, 2);
        //month
        $str .= '/' . substr($strTime, 2, 2);
        //year
        $str .= '/' . substr($strTime, 4, 4);
        //hour
        $str .= ' ' . substr($strTime, 8, 2);
        //minuts
        $str .= ':' . substr($strTime, 10, 2);
        //seconds
        $str .= ':' . substr($strTime, 12, 2);
        return $str;
    }

    public function GetJournal()
    {
        $responseData = ServerConnector::GetJournal($this);
        if ($responseData->isSuccess()) {
            $journalRecordCount = intval($responseData->XMLNestedFields->Response->Operations->Count[0]);

            $parsedResponse = Array('journal_record_count' => $journalRecordCount);
            $parsedResponse['operations'] = Array();

            $arOrders = $responseData->XMLNestedFields->Response->Operations->Order;
            foreach ($arOrders as $order) {
                $parsedOrder = Array(
                    'id' => intval($order['ID']),
                    'time' => $this->ConvertTime($order->Time[0]),
                    'amount' => (($order->Amount[0]) / 100),
                    'currency' => Helpers::DecodeCurrency($order->Currency[0]),
                    'type' => TypeEnums::GetLabel_OrderType($order->Type[0]),
                    'status' => TypeEnums::GetLabel_OrderStatus($order->Status[0]),
                    'two_id' => intval($order->twoId[0]),
                    'oper_type' => intval($order->OperType[0]),
                    'open_name' => TypeEnums::GetLabel_OperName($order->OperName[0])
                );
                $parsedResponse['operations'][] = $parsedOrder;
            }

            $responseData->SetParsedResponse($parsedResponse, 'journal');
        }

        return $responseData;
    }

    public function Reconcile()
    {
        $responseData = ServerConnector::Reconcile($this);
        if ($responseData->isSuccess()) {
            $reconcileParsedResponse = Array();

            $totals = $responseData->XMLNestedFields->Response->Totals;
            $reconcileParsedResponse['reconcilation'] = strval($responseData->XMLNestedFields->Response->Reconcilation[0]);
            $reconcileParsedResponse['debit'] = Array(
                'count' => intval($totals->Debit->Count[0]),
                'total_amount_formated' => number_format(((int)$totals->Debit->Amount[0]) / 100, 2, '.', ''),
                'total_amount' => ((float)$totals->Debit->Amount[0]) / 100
            );

            $reconcileParsedResponse['credit'] = Array(
                'count' => intval($totals->Credit->Count[0]),
                'total_amount_formated' => number_format(((int)$totals->Credit->Amount[0]) / 100, 2, '.', ''),
                'total_amount' => ((float)$totals->Credit->Amount[0]) / 100
            );

            $responseData->SetParsedResponse($reconcileParsedResponse, 'reconcile');
        }
        return $responseData;
    }

    public function getTWPG_OrderId()
    {
        return $this->ubrrOrderId;
    }

    public function getTWPG_SessionId()
    {
        return $this->ubrrSessionId;
    }

    public function getWorkMode()
    {
        return $this->workMode;
    }

    public function getCACertificateFile()
    {
        return $this->CACertificateFile;
    }

    public function getPublicCertificateFile()
    {
        return $this->publicCertificateFile;
    }

    public function getPrivateCertificateFile()
    {
        return $this->privateCertificateFile;
    }

    public function getPrivateCertificatePass()
    {
        return $this->privateCertificatePass;
    }

    //умножаем на 100, потому что передача в платежный шлюз в копейках
    public function getAmount()
    {
        return $this->orderAmount * 100;
    }

    public function getShopId()
    {
        return $this->shopId;
    }

    public function getApproveURL()
    {
        return $this->approveUrl;
    }

    public function getCancelURL()
    {
        return $this->cancelUrl;
    }

    public function getDeclineURL()
    {
        return $this->declineUrl;
    }

    public function Log($data)
    {
        if (!$this->useLogs) return false;

        if (!is_string($data))
            $data = print_r($data, true);
        else {
            if ($data === '[START]') {
                $data .= ' ' . date('d.m.Y h:i:s');
            }
        }

        file_put_contents($this->logFile, $data . "\r\n", FILE_APPEND);
    }

    public function LogErrors(DataContainer $response)
    {
        if (!$this->useLogs) return false;

        $arMessages = $response->getMessages();
        if (is_array($arMessages) && count($arMessages) > 0)
            foreach ($arMessages as $key => $list) {
                foreach ($list as $message) {
                    file_put_contents($this->logFile, "\t" . $key . ' ' . $message . "\r\n", FILE_APPEND);
                }
            }
    }

    /**
     * @return DataContainer
     */
    public function CheckSecurityConfiguration()
    {
        if (empty($this->shopId) || empty($this->publicCertificateFile) || empty($this->privateCertificateFile) || empty($this->CACertificateFile)) {
            $response = new DataContainer(false);

            if (empty($this->shopId))
                $response->AddError('Оплана не настроена. Обратитесь к администратору магазина');

            if (empty($this->publicCertificateFile)) {
                $validPublicFiles = $this->Certificates_DefaultPublicFiles();
                foreach ($validPublicFiles as $publicCertFile)
                    $response->AddError('Не найден файл публичного ключ [' . $publicCertFile . ']');
            }

            if (empty($this->privateCertificateFile)) {
                $validPrivateFiles = $this->Certificates_DefaultPrivateFiles();
                foreach ($validPrivateFiles as $privateCertFile)
                    $response->AddError('Не найден файл приватного ключа [' . $privateCertFile . ']');
            }
            if (empty($this->CACertificateFile))
                $response->AddError('Не найден файл банковского сертификата для связи с платежным шлюзом');

        } else {
            //Можно тут так же проверять на существования файлов - пока специально не делаем проверяя более глубокие ошибки CURL

            $response = new DataContainer(true);
        }

        return $response;
    }

    protected function ConvertCertificateToPEM($cerFile)
    {
        $certificateFilePath = substr($cerFile, 0, strrpos($cerFile, '.'));
        $certificatePEMFile = $certificateFilePath . '.pem';

        if (!file_exists($certificatePEMFile)) {
            if (file_exists($cerFile)) {
                $certificateCAcerContent = file_get_contents($cerFile);

                /* Convert .cer to .pem, cURL uses .pem */
                $certificateCApemContent = '-----BEGIN CERTIFICATE-----' . PHP_EOL
                    . chunk_split(base64_encode($certificateCAcerContent), 64, PHP_EOL)
                    . '-----END CERTIFICATE-----' . PHP_EOL;

                file_put_contents($certificatePEMFile, $certificateCApemContent);
            }
        }

        if (file_exists($certificatePEMFile)) {
            return $certificatePEMFile;
        }
        return false;
    }
}