<?php
namespace UBRIR;

use MongoDB\BSON\Type;

class DataContainer
{
    protected $success;
    protected $arMessages;
    protected $rawXML;
    private $XMLFields;
    private $XMLFields_KeyCaseLower;
    private $parsedResponse;
    public $XMLNestedFields;

    private $ResponseFields;

    function __construct($success = false, $arMessages = Array(), $workMode = CMS_Payment::WorkMode_Test)
    {
        $this->success = $success;
        $this->workMode = $workMode;

        if (is_array($arMessages)) {
            foreach ($arMessages as $code => $message) {
                $this->AddMessage($message, $code);
            }
        }

        return $this;
    }

    public function GetResponseStatus()
    {
        return strval($this->XMLNestedFields->Response->Status[0]);
    }

    public function SetParsedResponse($parsedResponse, $code = 'response')
    {
        $this->parsedResponse[strtolower($code)] = $parsedResponse;
        return $this;
    }

    public function GetParsedResponse()
    {
        return $this->parsedResponse;
    }

    public function AddMessage($message, $code)
    {
        if (!is_array($this->arMessages[$code]))
            $this->arMessages[$code] = Array();

        $this->arMessages[$code][] = $message;

        return $this;
    }

    public function AddError($message, $errorCode = '')
    {
        $this->success = false;

        if (!isset($this->arMessages['ERROR']))
            $this->arMessages['ERROR'] = Array();

        if (!empty($errorCode))
            $message = '[' . $errorCode . ']: ' . $message;

        $this->arMessages['ERROR'][] = $message;

        return $this;
    }

    public function setSuccess()
    {
        $this->success = true;

        return $this;
    }

    public function isSuccess()
    {
        return $this->success;
    }

    public function getRawXML()
    {
        return $this->rawXML;
    }

    public function GetMode()
    {
        return $this->workMode;
    }

    public function GetMessages()
    {
        return $this->arMessages;
    }

    public function GetErrors()
    {
        return $this->arMessages['ERROR'];
    }

    public function SaveXMLData($rawXML, $nestedXMLFields, $arXMLFields)
    {
        $this->rawXML = $rawXML;
        $this->XMLNestedFields = $nestedXMLFields;
        $this->XMLFields = $arXMLFields;
        $this->XMLFields_KeyCaseLower = array_change_key_case($arXMLFields, CASE_LOWER);

        return $this;
    }

    public function addFieldValue($code, $value)
    {
        $this->ResponseFields[$code] = $value;
    }

    public function getFieldValue($code)
    {
        $value = false;

        $lCode = strtolower($code);
        if (isset($this->XMLFields[$code]) || isset($this->XMLFields_KeyCaseLower[$lCode])) {
            if (isset($this->XMLFields[$code])) {
                $value = $this->XMLFields[$code];
            } else {
                $value = $this->XMLFields_KeyCaseLower[$lCode];
            }
        } elseif (isset($this->ResponseFields[$code]))
            $value = $this->ResponseFields[$code];

        return $value;
    }

    //Помощники для выдерания полей
    public function GetPaymentUrl($TWPG_OrderId, $SessionId)
    {
        $url = $this->getFieldValue('Url');
        if ($url)
            $url .= '?orderid=' . $TWPG_OrderId . '&sessionid=' . $SessionId;

        return $url;
    }

    public function GetTWPG_OrderId()
    {
        return $this->getFieldValue('OrderId');
    }

    public function GetSessionId()
    {
        return $this->getFieldValue('SessionId');
    }
}