<?php

namespace UBRIR;

class GatewayInteractionPanel extends SmartLogger
{
    protected $ubrrCoreDir;
    protected $logDir;
    protected $logFile;
    protected $useLogs;

    //XML Data
    protected $orderId;
    protected $ubrrOrderId; //twpg
    protected $ubrrSessionId; //twpg
    protected $orderAmount; //нужно умножать на 100 (потому что в копейках)
    protected $paymentUrl;
    protected $paymentStatus;

    protected $approveUrl;
    protected $cancelUrl;
    protected $declineUrl;

    protected $uniLogin;
    protected $uniPass;

    protected $CACertificateFile;
    protected $publicCertificateFile;
    protected $privateCertificateFile;

    private $serverConfigured = false;

    /**
     * @var InterfaceConnectionConfig
     */
    private $_connector;

    public function __construct(InterfaceConnectionConfig $connector = null, $useLogs = true)
    {
        if ($connector !== null)
            $this->_connector = $connector;

        $this->useLogs = $useLogs;

        $classesDir = realpath(dirname(__FILE__)) . '/';
        $this->ubrrCoreDir = realpath($classesDir . '/../') . '/';

        $this->logDir = $this->ubrrCoreDir . 'logs/';
        $this->logFile = $this->logDir . 'ubrr.log';

        $this->Log('[START]');
    }

    public function __destruct()
    {
        $this->Log('[END]');
    }

    public function GetViewsDir()
    {
        return $this->ubrrCoreDir . 'views/';
    }

    public function ConnectToCMS(InterfaceConnectionConfig $connector)
    {
        $this->_connector = $connector;
        return $this;
    }

    /**
     * @return InterfaceConnectionConfig
     * @throws \Exception
     */
    public function GetCMSConnector()
    {
        if ($this->_connector == null)
            throw new \Exception('Модуль не подключен к CMS');

        return $this->_connector;
    }

    //region Проброс методов от интерфейса InterfaceConnectionConfig
    public function getShopId()
    {
        $connector = $this->GetCMSConnector();

        return $connector->GetShopId();
    }

    public function GetOrderDataByUBRIROrderID($TWPG_OrderId)
    {
        $connector = $this->GetCMSConnector();

        return $connector->GetOrderDataByUBRIROrderID($TWPG_OrderId);
    }

    public function GetOrdersList($pageNum = 1, $perPageCount = 0)
    {
        $connector = $this->GetCMSConnector();

        return $connector->GetOrdersList($pageNum, $perPageCount);
    }

    public function SaveTWPGOrder($orderId, $TWPG_OrderId, $SessionId, $paymentId = false)
    {
        $connector = $this->GetCMSConnector();

        return $connector->SaveTWPGOrder($orderId, $TWPG_OrderId, $SessionId, $paymentId);
    }

    //endregion

    public function Certificates_DefaultPrivateFiles()
    {
        $shopId = $this->getShopId();
        if (empty($shopId)) {
            $shopId = '########';
        }

        $validPrivateFiles = Array();
        $validPrivateFiles[] = $this->ubrrCoreDir . 'certs/' . $shopId . '_private.key';
        $validPrivateFiles[] = $this->ubrrCoreDir . 'certs/' . $shopId . '_private.pem';
        $validPrivateFiles[] = $this->ubrrCoreDir . 'certs/user.key';

        return $validPrivateFiles;
    }

    public function Certificates_DefaultPublicFiles()
    {
        $shopId = $this->getShopId();
        if (empty($shopId)) {
            $shopId = '########';
        }

        $validPublicFiles = Array();
        $validPublicFiles[] = $this->ubrrCoreDir . 'certs/' . $shopId . '.pem';
        $validPublicFiles[] = $this->ubrrCoreDir . 'certs/user.pem';

        return $validPublicFiles;
    }

    /**
     * Заполняем проверяем настройки сертификатов для общения с сервером
     */
    public function ServerConnectionConfig($force = false, $publicCertificate = '', $privateCertificate = '', $privatePass = '')
    {
        if (!$this->serverConfigured || ($this->serverConfigured && $force)) {
            $connector = $this->GetCMSConnector();

            $this->shopId = $connector->GetShopId();

            if (!($this->shopId > 0)) {
                throw new \Exception('Не задан Shop ID');
            }

            $CACertificate = '';

            //$certFile = $this->ConvertCertificateToPEM($certFile);
            //$certFile = $UBRR_ROOT . "certs/cert.pem";

            //Сертификат банка
            if (!empty($CACertificate)) {
                //Проверка существует ли переданных сертификат
                if (!file_exists($CACertificate)) {
                    $CACertificate = false;
                }
            } else {
                //Поиск стандартного банковского сертификата
                $bankCAFile = 'bank';
                if ($connector->GetWorkMode()->IsTest()) {
                    $bankCAFile = 'bank_test';
                }

                $CACertificate = $this->ubrrCoreDir . 'certs/' . $bankCAFile . '.pem';
                if (!file_exists($CACertificate)) {
                    //Пробуем найти crt
                    $CACertificate = $this->ubrrCoreDir . 'certs/' . $bankCAFile . '.crt';
                    if (!file_exists($CACertificate)) {
                        $CACertificate = false;
                    }
                }
            }

            //Публичный сертификат
            if ($force && !empty($publicCertificate)) {
                if (!file_exists($publicCertificate)) {
                    $publicCertificate = false;
                }
            } else {
                //Поиск публичного сертификата в соответсвии с изначальными настройками
                $validPublicFiles = $this->Certificates_DefaultPublicFiles();

                $publicCertificate = false;
                foreach ($validPublicFiles as $publicCertFile)
                    if (file_exists($publicCertFile)) {
                        $publicCertificate = $publicCertFile;
                        break;
                    }
            }

            //Приватный сертификат
            if ($force && !empty($privateCertificate)) {
                if (!file_exists($privateCertificate)) {
                    $privateCertificate = false;
                }
            } else {
                //Поиск публичного сертификата в соответсвии с изначальными настройками

                $privateCertificate = false;
                $validPrivateFiles = $this->Certificates_DefaultPrivateFiles();
                foreach ($validPrivateFiles as $privateCertFile)
                    if (file_exists($privateCertFile)) {
                        $privateCertificate = $privateCertFile;

                        break;
                    }
            }

            if ($force && !empty($privatePass)) {
                $this->privateCertificatePass = $privatePass;
            } else {
                $this->privateCertificatePass = $connector->GetPrivateCertificatePassword();
            }

            $this->publicCertificateFile = $publicCertificate;
            $this->privateCertificateFile = $privateCertificate;
            $this->CACertificateFile = $CACertificate;

            $this->serverConfigured = true;
        }
    }

    /**
     * Проверяем что все необходимые поля для подготовки оплаты переданы и можно формировать XML к отправке
     */
    public function PrepareToPay()
    {
        //Проверка на заполненность всех необходимых полей
//        $Amount = $this->getAmount();
//        $Merchant = $this->getShopId();
//
//        $ApproveURL = $this->getApproveURL();
//        $CancelURL = $this->getCancelURL();
//        $DeclineURL = $this->getDeclineURL();

        $serverResponse = ServerConnector::PrepareToPay($this);

        return $serverResponse;
    }

    public function CheckOrderStatus()
    {
        $serverResponse = ServerConnector::GetOrderStatus($this);

        return $serverResponse;
    }

    //TODO: метод GetPaymentLink который выполняет SetupAndPrepareToPay обрабатывает его ошибки и если все хорошо то возвращает ссылку куда нужно перевести пользователя
    //Заполнение необходимых параметров и затем попытка передачи
    public function SetupAndPrepareToPay($orderId, $orderAmount, $approveCallbackURL, $cancelCallbackURL = '', $declineCallbackURL = '')
    {
        $this->orderId = $orderId;
        $this->orderAmount = $orderAmount;

        if (empty($cancelCallbackURL))
            $cancelCallbackURL = $approveCallbackURL;

        if (empty($declineCallbackURL))
            $declineCallbackURL = $approveCallbackURL;

        $this->approveUrl = $approveCallbackURL;
        $this->cancelUrl = $cancelCallbackURL;
        $this->declineUrl = $declineCallbackURL;

        return $this->PrepareToPay();
    }


    public function SetupAndGetOrderInformation($TWPG_OrderId, $SessionId)
    {
        $this->ubrrOrderId = $TWPG_OrderId;
        $this->ubrrSessionId = $SessionId;

        return $this->GetOrderInformation();
    }


    public function SetupAndCheckOrderStatus($TWPG_OrderId, $TWPG_SessionId)
    {
        $this->ubrrOrderId = $TWPG_OrderId;
        $this->ubrrSessionId = $TWPG_SessionId;

        return $this->CheckOrderStatus();
    }

    private function ConvertTime($strTime)
    {
        //date
        $str = substr($strTime, 0, 2);
        //month
        $str .= '/' . substr($strTime, 2, 2);
        //year
        $str .= '/' . substr($strTime, 4, 4);
        //hour
        $str .= ' ' . substr($strTime, 8, 2);
        //minuts
        $str .= ':' . substr($strTime, 10, 2);
        //seconds
        $str .= ':' . substr($strTime, 12, 2);
        return $str;
    }

    public function GetJournal()
    {
        $responseData = ServerConnector::GetJournal($this);
        if ($responseData->isSuccess()) {
            $journalRecordCount = intval($responseData->XMLNestedFields->Response->Operations->Count[0]);

            $parsedResponse = Array('journal_record_count' => $journalRecordCount);
            $parsedResponse['operations'] = Array();

            $arOrders = $responseData->XMLNestedFields->Response->Operations->Order;
            foreach ($arOrders as $order) {
                $parsedOrder = Array(
                    'id' => intval($order['ID']),
                    'time' => $this->ConvertTime($order->Time[0]),
                    'amount' => (($order->Amount[0]) / 100),
                    'currency' => Helpers::DecodeCurrency($order->Currency[0]),
                    'type' => TypeEnums::GetLabel_OrderType($order->Type[0]),
                    'status' => TypeEnums::GetLabel_OrderStatus($order->Status[0]),
                    'two_id' => intval($order->twoId[0]),
                    'oper_type' => intval($order->OperType[0]),
                    'open_name' => TypeEnums::GetLabel_OperName($order->OperName[0])
                );
                $parsedResponse['operations'][] = $parsedOrder;
            }

            $responseData->SetParsedResponse($parsedResponse, 'journal');
        }

        return $responseData;
    }

    public function Reconcile()
    {
        $responseData = ServerConnector::Reconcile($this);
        if ($responseData->isSuccess()) {
            $reconcileParsedResponse = Array();

            $totals = $responseData->XMLNestedFields->Response->Totals;
            $reconcileParsedResponse['reconcilation'] = strval($responseData->XMLNestedFields->Response->Reconcilation[0]);
            $reconcileParsedResponse['debit'] = Array(
                'count' => intval($totals->Debit->Count[0]),
                'total_amount_formated' => number_format(((int)$totals->Debit->Amount[0]) / 100, 2, '.', ''),
                'total_amount' => ((float)$totals->Debit->Amount[0]) / 100
            );

            $reconcileParsedResponse['credit'] = Array(
                'count' => intval($totals->Credit->Count[0]),
                'total_amount_formated' => number_format(((int)$totals->Credit->Amount[0]) / 100, 2, '.', ''),
                'total_amount' => ((float)$totals->Credit->Amount[0]) / 100
            );

            $responseData->SetParsedResponse($reconcileParsedResponse, 'reconcile');
            $responseData->CopyFieldsToResultArray();
        }
        return $responseData;
    }

    public function getTWPG_OrderId()
    {
        return $this->ubrrOrderId;
    }

    public function getShop_OrderId()
    {
        return $this->orderId;
    }

    public function getTWPG_SessionId()
    {
        return $this->ubrrSessionId;
    }

    /**
     * @return WorkMode
     */
    public function getWorkMode()
    {
        $connector = $this->GetCMSConnector();

        return $connector->GetWorkMode();
    }

    public function getCACertificateFile()
    {
        return $this->CACertificateFile;
    }

    public function getPublicCertificateFile()
    {
        return $this->publicCertificateFile;
    }

    public function getPrivateCertificateFile()
    {
        return $this->privateCertificateFile;
    }

    public function getPrivateCertificatePass()
    {
        return $this->privateCertificatePass;
    }

    public function GetCertificateGenerator()
    {
        return new NewCertificates($this);
    }

    //умножаем на 100, потому что передача в платежный шлюз в копейках
    public function getAmount()
    {
        return $this->orderAmount * 100;
    }

    public function getApproveURL()
    {
        return $this->approveUrl;
    }

    public function getCancelURL()
    {
        return $this->cancelUrl;
    }

    public function getDeclineURL()
    {
        return $this->declineUrl;
    }

    /**
     * @return DataContainer
     */
    public function CheckSecurityConfiguration()
    {
        if (empty($this->shopId) || empty($this->publicCertificateFile) || empty($this->privateCertificateFile) || empty($this->CACertificateFile)) {
            $response = new DataContainer(false);

            if (empty($this->shopId))
                $response->AddError('Оплата не настроена. Обратитесь к администратору магазина');

            if (empty($this->publicCertificateFile)) {
                $validPublicFiles = $this->Certificates_DefaultPublicFiles();
                foreach ($validPublicFiles as $publicCertFile)
                    $response->AddError('Не найден файл публичного ключа [' . $publicCertFile . ']');
            }

            if (empty($this->privateCertificateFile)) {
                $validPrivateFiles = $this->Certificates_DefaultPrivateFiles();
                foreach ($validPrivateFiles as $privateCertFile)
                    $response->AddError('Не найден файл приватного ключа [' . $privateCertFile . ']');
            }
            if (empty($this->CACertificateFile))
                $response->AddError('Не найден файл банковского сертификата для связи с платежным шлюзом');

        } else {
            //Можно тут так же проверять на существования файлов - пока специально не делаем проверяя более глубокие ошибки CURL

            $response = new DataContainer(true);
        }

        return $response;
    }

    /**
     * @return DataContainer
     */
    public function CheckServerEnvironmentConfiguration()
    {

        if (function_exists('curl_init')) {
            $response = new DataContainer(true);
        } else {
            $response = new DataContainer(false);
            $response->AddError('Не установлено расширение PHP Curl - работа модуля не возможна!');
        }
        return $response;
    }


    public function GetOrderInformation()
    {
        $serverResponse = ServerConnector::GetOrderInformation($this);

        if ($serverResponse->isSuccess()) {
            $orderInfo = $serverResponse->XMLNestedFields->Response->Order->row;

            $parsedResponse['ID'] = intval($orderInfo->id[0]);
            $parsedResponse['SessionID'] = strval($orderInfo->SessionID[0]);
            $parsedResponse['CreateDate'] = strval($orderInfo->createDate[0]);
            $parsedResponse['LastUpdateDate'] = strval($orderInfo->lastUpdateDate[0]);
            $parsedResponse['PayDate'] = strval($orderInfo->payDate[0]);
            $parsedResponse['MerchantID'] = strval($orderInfo->MerchantID[0]);
            $parsedResponse['Amount'] = floatval($orderInfo->Amount[0]) / 100;
            $parsedResponse['Currency'] = strval($orderInfo->Currency[0]);
            $parsedResponse['OrderLanguage'] = strval($orderInfo->OrderLanguage[0]);
            $parsedResponse['Description'] = strval($orderInfo->Description[0]);
            $parsedResponse['ApproveURL'] = strval($orderInfo->ApproveURL[0]);
            $parsedResponse['CancelURL'] = strval($orderInfo->CancelURL[0]);
            $parsedResponse['DeclineURL'] = strval($orderInfo->DeclineURL[0]);
            $parsedResponse['OrderStatus'] = TypeEnums::GetLabel_OrderStatus($orderInfo->Orderstatus[0]);
            $parsedResponse['RefundAmount'] = strval($orderInfo->RefundAmount[0]);
            $parsedResponse['RefundCurrency'] = strval($orderInfo->RefundCurrency[0]);
            $parsedResponse['ExtSystemProcess'] = strval($orderInfo->ExtSystemProcess[0]);
            $parsedResponse['OrderType'] = TypeEnums::GetLabel_OrderType($orderInfo->OrderType[0]);
            $parsedResponse['Fee'] = strval($orderInfo->Fee[0]);
            $parsedResponse['RefundDate'] = strval($orderInfo->RefundDate[0]);
            $parsedResponse['TWODate'] = strval($orderInfo->TWODate[0]);
            $parsedResponse['TWOTime'] = strval($orderInfo->TWOTime[0]);

            $parsedResponse['Operations'] = Array();
            $arOperations = $orderInfo->OrderOperations->row;
            foreach ($arOperations as $operation) {
                $formattedOperation = Array(
                    'PackageId' => strval($operation->PackageId[0]),
                    'CreateDate' => strval($operation->createDate[0]),
                    'MerchantID' => strval($operation->MerchantID[0]),
                    'OperType' => strval($operation->OperType[0]),
                    'OperName' => TypeEnums::GetLabel_OperName($operation->OperName[0]),
                    'OrderId' => strval($operation->OrderId[0]),
                    'Amount' => floatval($operation->Amount[0]) / 100,
                    'Currency' => strval($operation->Currency[0]),
                    'Approval' => strval($operation->Approval[0]),
                    'TwoId' => strval($operation->twoId[0]),
                );

                $parsedResponse['Operations'][] = $formattedOperation;
            }

            $serverResponse->SetParsedResponse($parsedResponse, 'orderinfo');
        }


        return $serverResponse;
    }


    //region Работа с сертификатами

    protected function ConvertCertificateToPEM($cerFile)
    {
        $certificateFilePath = substr($cerFile, 0, strrpos($cerFile, '.'));
        $certificatePEMFile = $certificateFilePath . '.pem';

        if (!file_exists($certificatePEMFile)) {
            if (file_exists($cerFile)) {
                $certificateCAcerContent = file_get_contents($cerFile);

                /* Convert .cer to .pem, cURL uses .pem */
                $certificateCApemContent = '-----BEGIN CERTIFICATE-----' . PHP_EOL
                    . chunk_split(base64_encode($certificateCAcerContent), 64, PHP_EOL)
                    . '-----END CERTIFICATE-----' . PHP_EOL;

                file_put_contents($certificatePEMFile, $certificateCApemContent);
            }
        }

        if (file_exists($certificatePEMFile)) {
            return $certificatePEMFile;
        }
        return false;
    }

    //endregion

    public function ShowPaymentError($continueLink, $errorMessage = '', PaymentResultViewer $resultViewer = null)
    {
        $connector = $this->GetCMSConnector();

        if (empty($continueLink))
            $continueLink = $connector->GetDefaultContinueLink();

        if ($resultViewer == null)
            $resultViewer = new PaymentResultViewer();

        if (!empty($errorMessage))
            $resultViewer->SetFailureMessage($errorMessage);

        global $view_data;
        $view_data = $resultViewer
            ->SetContinueLink($continueLink)
            ->ViewData();

        $viewDir = $this->GetViewsDir();
        $templateFile = $viewDir . '/ubrr.view.paymentstatus.php';
        include_once($templateFile);
    }

    /**
     * Сохраняем данные о заказе и показываем страницу статуса оплаты
     * @param $continueLink
     * @param string $message
     * @param PaymentResultViewer|null $resultData
     */
    public function ShowPaymentSuccess($continueLink, $message = '', PaymentResultViewer $resultData = null)
    {
        $connector = $this->GetCMSConnector();

        if (empty($continueLink))
            $continueLink = $connector->GetDefaultContinueLink();

        if ($resultData == null)
            $resultData = new PaymentResultViewer();

        global $view_data;
        $view_data = $resultData
            ->SetSuccessMessage($message)
            ->SetContinueLink($continueLink)
            ->ViewData();

        $viewDir = $this->GetViewsDir();
        $templateFile = $viewDir . '/ubrr.view.paymentstatus.php';
        include_once($templateFile);
    }
}