<?php

namespace UBRIR;

class TypeEnums
{
    const ResponseStatus_Success = '00';
    const ResponseStatus_DontHaveAccessForOperation = '10';
    const ResponseStatus_WrongRequestFormat = '30';
    const ResponseStatus_WrongOperation = '54';
    const ResponseStatus_TWPG_Forbidden = '95';
    const ResponseStatus_SystemError = '96';

    const OrderStatus_APPROVED = 'APPROVED';
    const OrderStatus_DECLINED = 'DECLINED';
    const OrderStatus_CANCELED = 'CANCELED';
    const OrderStatus_REVERSED = 'REVERSED';
    const OrderStatus_REFUNDED = 'REFUNDED';
    const OrderStatus_EXPIRED = 'EXPIRED';
    const OrderStatus_PREAUTH_APPROVED = 'PREAUTH-APPROVED';
    const OrderStatus_ON_PAYMENT = 'OrderStatus_ON-PAYMENT';

    const OrderType_Purchase = 'Purchase';
    const OrderType_Reverse = 'Reverse';

    const OperName_CreateOrder = 'CreateOrder';
    const OperName_GetOrderStatus = 'GetOrderStatus';
    const OperName_Purchase = 'Purchase';
    const OperName_Reverse = 'Reverse';
    const OperName_Reconcile = 'Reconcile';
    const OperName_TransactionLog = 'TransactionLog';
    const OperName_GetOrderInformation = 'GetOrderInformation';

    // Константы-массивы не поддерживаются в php 5.3
    // const Lang = Array('ru' => Array(

    static $Lang = Array('ru' => Array(
        'ResponseStatus' => Array(
            TypeEnums::ResponseStatus_Success => 'Операция успешно выполнена',
            TypeEnums::ResponseStatus_DontHaveAccessForOperation => 'ИМ не имеет доступа к этой операции',
            TypeEnums::ResponseStatus_WrongRequestFormat => 'Неверный формат запроса',
            TypeEnums::ResponseStatus_WrongOperation => 'Недопустимая операция',
            TypeEnums::ResponseStatus_TWPG_Forbidden => 'TWPG не позволяет провести данную операцию',
            TypeEnums::ResponseStatus_SystemError => 'Системная ошибка',
        ),
        'OrderStatus' => Array(
            TypeEnums::OrderStatus_APPROVED => 'Одобрен (оплата прошла успешно)',
            TypeEnums::OrderStatus_DECLINED => 'Отказ в оплате',
            TypeEnums::OrderStatus_CANCELED => 'Платеж отменен пользователем', //Отменен (клиент прервал выполнение операции)
            TypeEnums::OrderStatus_REVERSED => 'Средства вернули плательщику', //Реверсирован
            TypeEnums::OrderStatus_REFUNDED => 'Осуществлен возврат товара',
            TypeEnums::OrderStatus_PREAUTH_APPROVED => 'Выполнена предавторизация',
            TypeEnums::OrderStatus_ON_PAYMENT => 'Производиться оплата', //На оплате
            TypeEnums::OrderStatus_EXPIRED => 'Истек срок действия заказа',
        ),
        'OrderType' => Array(
            TypeEnums::OrderType_Purchase => 'Покупка',
            TypeEnums::OrderType_Reverse => 'Реверс оплаты',
        ),
        'OperName' => Array(
            TypeEnums::OperName_CreateOrder => 'Создание заказа на покупку',
            TypeEnums::OperName_GetOrderStatus => 'Получение статуса заказа',
            TypeEnums::OperName_Purchase => 'Покупка',
            TypeEnums::OperName_Reverse => 'Реверс оплаты',
            TypeEnums::OperName_Reconcile => 'Сверка итогов',
            TypeEnums::OperName_TransactionLog => 'Журнал операций',
            TypeEnums::OperName_GetOrderInformation => 'Получение информации о заказе',
        )
    ));

    public static function isValidOrderState($orderState)
    {
        if ($orderState == self::OrderStatus_APPROVED ||
            $orderState == self::OrderStatus_CANCELED ||
            $orderState == self::OrderStatus_DECLINED ||
            $orderState == self::OrderStatus_EXPIRED ||
            $orderState == self::OrderStatus_ON_PAYMENT ||
            $orderState == self::OrderStatus_PREAUTH_APPROVED ||
            $orderState == self::OrderStatus_ON_PAYMENT
        )
            return true;

        return false;
    }

    public static function GetLabel_ResponseStatus($paramCode, $languageCode = 'ru')
    {
        return self::GetLabel('ResponseStatus', $paramCode, $languageCode);
    }

    public static function GetLabel_OrderStatus($paramCode, $languageCode = 'ru')
    {
        return self::GetLabel('OrderStatus', $paramCode, $languageCode);
    }

    public static function GetLabel_OrderType($paramCode, $languageCode = 'ru')
    {
        return self::GetLabel('OrderType', $paramCode, $languageCode);
    }

    public static function GetLabel_OperName($paramCode, $languageCode = 'ru')
    {
        return self::GetLabel('OperName', $paramCode, $languageCode);
    }

    public static function GetLabel($prefix, $paramCode, $languageCode = 'ru')
    {
        $lang = self::$Lang;

        $paramCode = strval($paramCode); //На случай если передается SimpleXMLElemen

        if (!empty($prefix)) {
            if (isset($lang[$languageCode])) {
                if (isset($lang[$languageCode][$prefix]))
                    if (isset($lang[$languageCode][$prefix][$paramCode]))
                        return $lang[$languageCode][$prefix][$paramCode];
            }
        }
        return false;
    }

    public static function GetCountryList()
    {
        $arCountries = Array("Австралия" => "AU",
            "Австрия" => "AT",
            "Азербайджан" => "AZ",
            "Албания" => "AL",
            "Алжир" => "DZ",
            "Американские Виргинские острова" => "VI",
            "Американское Самоа" => "AS",
            "Ангилья" => "AI",
            "Ангола" => "AO",
            "Андорра" => "AD",
            "Антарктида" => "AQ",
            "Антигуа и Барбуда" => "AG",
            "Аргентина" => "AR",
            "Армения" => "AM",
            "Аруба" => "AW",
            "Афганистан" => "AF",
            "Багамские острова" => "BS",
            "Бангладеш" => "BD",
            "Барбадос" => "BB",
            "Бахрейн" => "BH",
            "Белиз" => "BZ",
            "Белоруссия" => "BY",
            "Бельгия" => "BE",
            "Бенин" => "BJ",
            "Бермуды" => "BM",
            "Болгария" => "BG",
            "Боливия" => "BO",
            "Бонайре, Синт-Эстатиус и Саба" => "BQ",
            "Босния и Герцеговина" => "BA",
            "Ботсвана" => "BW",
            "Бразилия" => "BR",
            "Британская территория в Индийском океане" => "IO",
            "Британские Виргинские острова" => "VG",
            "Бруней" => "BN",
            "Буве" => "BV",
            "Буркина-Фасо" => "BF",
            "Бурунди" => "BI",
            "Бутан" => "BT",
            "Вануату" => "VU",
            "Ватикан" => "VA",
            "Великобритания" => "GB",
            "Венгрия" => "HU",
            "Венесуэла" => "VE",
            "Восточный Тимор (Тимор-Лешти)" => "TL",
            "Вьетнам" => "VN",
            "Габон" => "GA",
            "Гаити" => "HT",
            "Гайана" => "GY",
            "Гамбия" => "GM",
            "Гана" => "GH",
            "Гваделупа" => "GP",
            "Гватемала" => "GT",
            "Гвинея" => "GN",
            "Гвинея-Бисау" => "GW",
            "Германия" => "DE",
            "Гернси" => "GG",
            "Гибралтар" => "GI",
            "Гондурас" => "HN",
            "Гонконг" => "HK",
            "Гренада" => "GD",
            "Гренландия" => "GL",
            "Греция" => "GR",
            "Грузия" => "GE",
            "Гуам" => "GU",
            "Дания" => "DK",
            "Демократическая Республика Конго" => "CD",
            "Джерси" => "JE",
            "Джибути" => "DJ",
            "Доминика" => "DM",
            "Доминикана" => "DO",
            "Египет" => "EG",
            "Замбия" => "ZM",
            "Западная Сахара (Сахарская Арабская Демократическая Республика)" => "EH",
            "Зимбабве" => "ZW",
            "Израиль" => "IL",
            "Индия" => "IN",
            "Индонезия, Бали" => "ID",
            "Иордания" => "JO",
            "Ирак" => "IQ",
            "Иран" => "IR",
            "Ирландия" => "IE",
            "Исландия" => "IS",
            "Испания" => "ES",
            "Италия" => "IT",
            "Йемен" => "YE",
            "Кабо-Верде (Острова Зеленого Мыса)" => "CV",
            "Казахстан" => "KZ",
            "Каймановы острова" => "KY",
            "Камбоджа" => "KH",
            "Камерун" => "CM",
            "Канада" => "CA",
            "Катар" => "QA",
            "Кения" => "KE",
            "Кипр" => "CY",
            "Киргизия" => "KG",
            "Кирибати" => "KI",
            "Китай" => "CN",
            "КНДР" => "KP",
            "Кокосовые острова (Килинг)" => "CC",
            "Колумбия" => "CO",
            "Коморские острова" => "KM",
            "Корея" => "KR",
            "Коста-Рика" => "CR",
            "Кот-д’Ивуар (Берег Слоновой Кости)" => "CI",
            "Куба" => "CU",
            "Кувейт" => "KW",
            "Кюрасао" => "CW",
            "Лаос" => "LA",
            "Латвия" => "LV",
            "Лесото" => "LS",
            "Либерия" => "LR",
            "Ливан" => "LB",
            "Ливия" => "LY",
            "Литва" => "LT",
            "Лихтенштейн" => "LI",
            "Люксембург" => "LU",
            "Маврикий" => "MU",
            "Мавритания" => "MR",
            "Мадагаскар" => "MG",
            "Майотта" => "YT",
            "Макао (Аомынь)" => "MO",
            "Македония" => "MK",
            "Малави" => "MW",
            "Малайзия" => "MY",
            "Мали" => "ML",
            "Мальдивы" => "MV",
            "Мальта" => "MT",
            "Марокко" => "MA",
            "Мартиника" => "MQ",
            "Маршалловы острова" => "MH",
            "Мексика" => "MX",
            "Мозамбик" => "MZ",
            "Молдавия" => "MD",
            "Монако" => "MC",
            "Монголия" => "MN",
            "Монтсеррат" => "MS",
            "Мьянма (Бирма)" => "MM",
            "Намибия" => "NA",
            "Науру" => "NR",
            "Непал" => "NP",
            "Нигер" => "NE",
            "Нигерия" => "NG",
            "Нидерландские Антильские острова" => "AN",
            "Нидерланды (Голландия)" => "NL",
            "Никарагуа" => "NI",
            "Ниуэ" => "NU",
            "Новая Зеландия" => "NZ",
            "Новая Каледония" => "NC",
            "Норвегия" => "NO",
            "ОАЭ" => "AE",
            "Оман" => "OM",
            "Остров Норфолк" => "NF",
            "Остров Рождества" => "CX",
            "Остров Святой Елены" => "SH",
            "Остров Херд и острова Макдональд" => "HM",
            "Острова Кука" => "CK",
            "Острова Питкэрн" => "PN",
            "Острова Тёркс и Кайкос" => "TC",
            "Острова Уоллис и Футуна" => "WF",
            "Пакистан" => "PK",
            "Палау" => "PW",
            "Палестина" => "PS",
            "Панама" => "PA",
            "Папуа" => "PG",
            "Парагвай" => "PY",
            "Перу" => "PE",
            "Польша" => "PL",
            "Португалия" => "PT",
            "Пуэрто-Рико" => "PR",
            "Республика Конго" => "CG",
            "Реюньон" => "RE",
            "Россия" => "RU",
            "Руанда" => "RW",
            "Румыния" => "RO",
            "Сальвадор" => "SV",
            "Самоа" => "WS",
            "Сан-Марино" => "SM",
            "Сан-Томе и Принсипи" => "ST",
            "Саудовская Аравия" => "SA",
            "Свазиленд" => "SZ",
            "Северные Марианские острова" => "MP",
            "Сейшелы" => "SC",
            "Сен-Пьер и Микелон" => "PM",
            "Сенегал" => "SN",
            "Сент-Винсент и Гренадины" => "VC",
            "Сент-Китс и Невис" => "KN",
            "Сент-Люсия" => "LC",
            "Сербия" => "RS",
            "Сингапур" => "SG",
            "Сирия" => "SY",
            "Словакия" => "SK",
            "Словения" => "SI",
            "Соломоновы острова" => "SB",
            "Сомали" => "SO",
            "Судан" => "SD",
            "Суринам" => "SR",
            "США" => "US",
            "Сьерра-Леоне" => "SL",
            "Таджикистан" => "TJ",
            "Таиланд" => "TH",
            "Тайвань" => "TW",
            "Танзания" => "TZ",
            "Того" => "TG",
            "Токелау" => "TK",
            "Тонга" => "TO",
            "Тринидад и Тобаго" => "TT",
            "Тувалу" => "TV",
            "Тунис" => "TN",
            "Туркмения" => "TM",
            "Турция" => "TR",
            "Уганда" => "UG",
            "Узбекистан" => "UZ",
            "Украина" => "UA",
            "Уругвай" => "UY",
            "Фарерские острова" => "FO",
            "Федеративные Штаты Микронезии" => "FM",
            "Фиджи" => "FJ",
            "Филиппины" => "PH",
            "Финляндия" => "FI",
            "Фолклендские (Мальвинские) острова" => "FK",
            "Франция" => "FR",
            "Французская Гвиана" => "GF",
            "Французская Полинезия (Таити)" => "PF",
            "Французские Южные и Антарктические Территории" => "TF",
            "Хорватия" => "HR",
            "Центральноафриканская Республика" => "CF",
            "Чад" => "TD",
            "Черногория" => "ME",
            "Чехия" => "CZ",
            "Чили, о. Пасхи" => "CL",
            "Чуук (Трук)" => "FM",
            "Швейцария" => "CH",
            "Швеция" => "SE",
            "Шпицберген и Ян-Майен" => "SJ",
            "Шри-Ланка (Цейлон)" => "LK",
            "Эквадор, Галапагосы" => "EC",
            "Экваториальная Гвинея" => "GQ",
            "Эритрея" => "ER",
            "Эстония" => "EE",
            "Эфиопия" => "ET",
            "ЮАР" => "ZA",
            "Южная Георгия и Южные Сандвичевы острова" => "GS",
            "Ямайка" => "JM",
            "Яп" => "FM",
            "Япония" => "JP",
        );

        return $arCountries;
    }

    public static function GetRuRegionList()
    {
        //https://ru.wikipedia.org/wiki/ISO_3166-2:RU
        $arRuRegionsList = Array(
            "Адыгея" => "AD",
            "Алтайский край" => "ALT",
            "Амурская область" => "AMU",
            "Архангельская область" => "ARK",
            "Астраханская область" => "AST",
            "Башкортостан" => "BA",
            "Белгородская область" => "BEL",
            "Брянская область" => "BRY",
            "Бурятия" => "BU",
            "Владимирская область" => "VLA",
            "Волгоградская область" => "VGG",
            "Вологодская область" => "VLG",
            "Воронежская область" => "VOR",
            "Дагестан" => "DA",
            "Забайкальский край" => "ZAB",
            "Ивановская область" => "IVA",
            "Ингушетия" => "IN",
            "Иркутская область" => "IRK",
            "Кабардино-Балкария" => "KB",
            "Калининградская область" => "KGD",
            "Калмыкия" => "KL",
            "Калужская область" => "KLU",
            "Камчатский край" => "KAM",
            "Карачаево-Черкесия" => "KC",
            "Карелия" => "KR",
            "Кемеровская область" => "KEM",
            "Кировская область" => "KIR",
            "Костромская область" => "KOS",
            "Краснодарский край" => "KDA",
            "Красноярский край" => "KYA",
            "Курганская область" => "KGN",
            "Курская область" => "KRS",
            "Ленинградская область" => "LEN",
            "Липецкая область" => "LIP",
            "Магаданская область" => "MAG",
            "Марий Эл" => "ME",
            "Мордовия" => "MO",
            "Москва" => "MOW",
            "Московская область" => "MOS",
            "Мурманская область" => "MUR",
            "Ненецкий автономный округ" => "NEN",
            "Нижегородская область" => "NIZ",
            "Новгородская область" => "NGR",
            "Новосибирская область" => "NVS",
            "Омская область" => "OMS",
            "Оренбургская область" => "ORE",
            "Орловская область" => "ORL",
            "Пензенская область" => "PNZ",
            "Пермский край" => "PER",
            "Приморский край" => "PRI",
            "Псковская область" => "PSK",
            "Республика Алтай" => "AL",
            "Республика Коми" => "KO",
            "Республика Саха" => "SA",
            "Ростовская область" => "ROS",
            "Рязанская область" => "RYA",
            "Самарская область" => "SAM",
            "Санкт-Петербург" => "SPE",
            "Саратовская область" => "SAR",
            "Сахалинская область" => "SAK",
            "Свердловская область" => "SVE",
            "Северная Осетия" => "SE",
            "Смоленская область" => "SMO",
            "Ставропольский край" => "STA",
            "Тамбовская область" => "TAM",
            "Татарстан" => "TA",
            "Тверская область" => "TVE",
            "Томская область" => "TOM",
            "Тульская область" => "TUL",
            "Тыва" => "TY",
            "Тюменская область" => "TYU",
            "Удмуртия" => "UD",
            "Ульяновская область" => "ULY",
            "Хабаровский край" => "KHA",
            "Хакасия" => "KK",
            "Ханты-Мансийский автономный округ — Югра" => "KHM",
            "Челябинская область" => "CHE",
            "Чечня" => "CE",
            "Чувашия" => "CU",
            "Чукотский автономный округ" => "CHU",
            "Ямало-Ненецкий автономный округ" => "YAN",
            "Ярославская область" => "YAR"
        );

        return $arRuRegionsList;
    }

    public static function GetRuCityList()
    {
        return Array(
            "Абаза",
            "Абакан",
            "Абан",
            "Абатский",
            "Абдулино",
            "Абинск",
            "Авангардное",
            "Агаповка",
            "Агинское",
            "Агрыз",
            "Адамовка",
            "Адлер",
            "Адреаполь",
            "Адыгейск",
            "Адыге-Хабль",
            "Азнакаево",
            "Азов",
            "Азово",
            "Айкино",
            "Акбулак",
            "Акбулак",
            "Аксай",
            "Аксубаево",
            "Актаныш",
            "Акулово",
            "Акша",
            "Акъяр",
            "Алагир",
            "Алапаевск",
            "Алатырь",
            "Алдан",
            "Алеевка",
            "Алейск",
            "Александров",
            "Александров Гай",
            "Александровка",
            "Александровка",
            "Александровск",
            "Александровское",
            "Александровское",
            "Александро-Невский",
            "Алексеевка",
            "Алексеевка",
            "Алексеевка",
            "Алексеевское",
            "Алексин",
            "Аликово",
            "Алнаши",
            "Алтайское",
            "Алькеево",
            "Альменево",
            "Альметьевск",
            "Амга",
            "Амурск",
            "Анадырь",
            "Анапа",
            "Ангарск",
            "Анжеро-Судженск",
            "Анна",
            "Антропово",
            "Анучино",
            "Апастово",
            "Апатиты",
            "Апшеронск",
            "Арбаж",
            "Аргаяш",
            "Аргун",
            "Ардатов",
            "Ардатов",
            "Ардон",
            "Арзамас",
            "Арзгир",
            "Аркадак",
            "Армавир",
            "Армизонское",
            "Аромашево",
            "Арсеньев",
            "Арсеньево",
            "Арск",
            "Артем",
            "Артемовский",
            "Арти",
            "Архангельск",
            "Архангельское",
            "Архангельское",
            "Архонская",
            "Асбест",
            "Асекеево",
            "Асино",
            "Аскарово",
            "Аскиз",
            "Аскино",
            "Астрахань",
            "Аткарск",
            "Атня",
            "Атюрьево",
            "Атяшево",
            "Ахтубинск-1",
            "Ачайваям",
            "Ачинск",
            "Ачинское",
            "Ачит",
            "Ачхой-Мартан",
            "Аша",
            "Аше",
            "Аян",
            "Бабаево",
            "Бабушкино",
            "Бабынино",
            "Бавлы",
            "Багаевский",
            "Баган",
            "Багратионово",
            "Багратионовск",
            "Баево",
            "Базарный Карабулак",
            "Базарный Сызган",
            "Байкалово",
            "Байконур",
            "Баймак",
            "Бакалы",
            "Баксан",
            "Бакчар",
            "Балабаново",
            "Балаково",
            "Балахна",
            "Балахта",
            "Балашов",
            "Балезино",
            "Балтай",
            "Балтаси",
            "Балтийск",
            "Барабинск",
            "Баргузин",
            "Барда",
            "Барнаул",
            "Барыш",
            "Батагай-Алыта",
            "Батайск",
            "Батецкий",
            "Батырево",
            "Башмаково",
            "Беднодемьяновск",
            "Бежаницы",
            "Бежецк",
            "Безенчук",
            "Бекенево",
            "Беково",
            "Белая",
            "Белая Глина",
            "Белая Калитва",
            "Белая Холуница",
            "Белгород",
            "Белебей",
            "Белебей",
            "Белев",
            "Белинский",
            "Белкино",
            "Белово",
            "Белогорск",
            "Белозерск",
            "Белозерское",
            "Белокуриха",
            "Беломорск",
            "Белорецк",
            "Белореченск",
            "Белоярский",
            "Белоярский",
            "Белый",
            "Белый яр",
            "Белый Яр",
            "Белый Яр",
            "Беляевка",
            "Бердигестях",
            "Бердск",
            "Бердюжье",
            "Береговое",
            "Березник",
            "Березники",
            "Березовка",
            "Березовка",
            "Березовка",
            "Березовка",
            "Березовка",
            "Березово",
            "Березовский",
            "Березовский",
            "Беслан",
            "Бессоновка",
            "Бея",
            "Бижбуляк",
            "Бийск",
            "Бикин",
            "Биробиджан",
            "Бирск",
            "Бирюлюсы",
            "Бичура",
            "Благовещенка",
            "Благовещенск",
            "Благовещенск",
            "Благодарный",
            "Ближнее",
            "Бобров",
            "Богатово",
            "Богатые Сабы",
            "Богданович",
            "Боговарово",
            "Богородицк",
            "Богородск",
            "Богородское",
            "Богородское",
            "Боготол",
            "Боград",
            "Богучаны",
            "Богучар",
            "Боковская",
            "Бокситогорск",
            "Болгар",
            "Бологое",
            "Болотное",
            "Болхов",
            "Большаково",
            "Большая Глушица",
            "Большая Мартыновка",
            "Большая Мурта",
            "Большая Поляна",
            "Большая Соснова",
            "Большая Черниговка",
            "Большеречье",
            "Большеустьикинское",
            "Большие Березняки",
            "Большие Горки",
            "Большие Уки",
            "Большое Болдино",
            "Большое Игнатово",
            "Большое Мурашкино",
            "Большое Нагаткино",
            "Большое село",
            "Большое Село",
            "Большое Солдатское",
            "Большое Сорокино",
            "Большой Камень",
            "Большой Улуй",
            "Большой Царын",
            "Бондари",
            "Бор",
            "Борзя",
            "Борисовка",
            "Борисоглебск",
            "Борисоглебский",
            "Боровичи",
            "Боровск",
            "Борогонцы",
            "Бородино",
            "Борское",
            "Борское",
            "Братск",
            "Бреды",
            "Брейтово",
            "Брюховецкая",
            "Брянск",
            "Брянское",
            "Бугульма",
            "Бугуруслан",
            "Буденновск",
            "Буздяк",
            "Бузулук",
            "Буинск",
            "Буй",
            "Бураево",
            "Бурла",
            "Бутурлино",
            "Бутурлиновка",
            "Быстрый Исток",
            "Бычково",
            "Вавож",
            "Вагай",
            "Вад",
            "Вадинск",
            "Валдай",
            "Валуйки",
            "Ванино",
            "Варгаши",
            "Вардане",
            "Варна",
            "Варнавино",
            "Васильево",
            "Васильково",
            "Вача",
            "Ведено",
            "Вейделевка",
            "Велиж",
            "Великие Луки",
            "Великий Новгород",
            "Великий Устюг",
            "Великолукское",
            "Вельск",
            "Венгерово",
            "Венев",
            "Верещагино",
            "Верний бисер",
            "Верхневилюйск",
            "Верхнеуральск",
            "Верхнеяркеево",
            "Верхние Киги",
            "Верхний Ландех",
            "Верхний Мамон",
            "Верхний Услон",
            "Верхний Уфалей",
            "Верхняя Пышма",
            "Верхняя Салда",
            "Верхняя Тойма",
            "Верхняя Хава",
            "Верховажье",
            "Верховье",
            "Верхотурье",
            "Верхошижемье",
            "Верх-Усугли",
            "Верх-Чебула",
            "Веселый",
            "Весново",
            "Ветлуга",
            "Вешенская",
            "Вешкайма",
            "Взморье",
            "Визинга",
            "Викулово",
            "Вилюйск",
            "Вилючинск",
            "Вилючинск-3",
            "Вичуга",
            "Вишневка",
            "Вишневое",
            "Вишневское",
            "Вишневый",
            "Владивосток",
            "Владикавказ",
            "Владимир",
            "Владимиро-Александровское",
            "Владимирово",
            "Вожега",
            "Вознесенское",
            "Волгоград",
            "Волгодонск",
            "Волгореченск",
            "Волжск",
            "Волово",
            "Волово",
            "Вологда",
            "Володаровка",
            "Володарский",
            "Волоколамск",
            "Волоконовка",
            "Волосово",
            "Волот",
            "Волочаевское",
            "Волхов",
            "Волчиха",
            "Вольное",
            "Вольно-Надеждинское",
            "Вольск",
            "Воркута",
            "Воробьевка",
            "Воробьево",
            "Воронеж",
            "Воротынец",
            "Воскресенск",
            "Воскресенское",
            "Воскресенское",
            "Восод",
            "Воткинск",
            "Вохма",
            "Всеволожск",
            "Вуктыл",
            "Вурнары",
            "Выборг",
            "Выгоничи",
            "Выкса",
            "Выльгорт",
            "Выльногорск",
            "Выселки",
            "Высокая Гора",
            "Высокое",
            "Высокое",
            "Вытегра",
            "Вышний Волочек",
            "Вяземский",
            "Вязяма",
            "Вятские Поляны",
            "Гаврилов Посад",
            "Гавриловка-2",
            "Гаврилово",
            "Гаврилов-ям",
            "Гагарин",
            "Гагино",
            "Гай",
            "Галич",
            "Гальбштадт",
            "Гастеллово",
            "Гатчина",
            "Гвардейск",
            "Гвардейское",
            "Гдов",
            "Геленджик",
            "Георгиевск",
            "Георгиевское",
            "Георгиевское",
            "Гиагинская",
            "Глазов",
            "Глазуновка",
            "Глинка",
            "Глушково",
            "Глушково",
            "Глядянское",
            "Голицыно",
            "Головкино",
            "Голышманово",
            "Гончарово",
            "Гордеевка",
            "Гордое",
            "Горно-Алтайск",
            "Горнозаводск",
            "Горный",
            "Горняк",
            "Городец",
            "Городище",
            "Городовиковск",
            "Гороховец",
            "Горшечное",
            "Горьковское",
            "Горячий Ключ",
            "Грайворон",
            "Грахово",
            "Грачевка",
            "Грачевка",
            "Грачевка",
            "Гремячинск",
            "Грибановский",
            "Грибки",
            "Грозный",
            "Громово",
            "Грязи",
            "Грязовец",
            "Губаха",
            "Губкин",
            "Губкинский",
            "Гудермес",
            "Гуково",
            "Гулькевичи",
            "Гурьевск",
            "Гурьевск",
            "Гусев",
            "Гусево",
            "Гусиноозерск",
            "Гусь Хрустальный",
            "Давлеканово",
            "Далматово",
            "Дальнегорск",
            "Дальнее",
            "Дальнее",
            "Дальнее",
            "Дальнее Константиново",
            "Дальнереченск",
            "Данилов",
            "Данков",
            "Даровский",
            "Дворкино",
            "Дебесы",
            "Дедовичи",
            "Демидов",
            "Демидово",
            "Демянск",
            "Дербент",
            "Дергачи",
            "Десногорск",
            "Дзержинск",
            "Дзержинск",
            "Дивеево",
            "Дивногорск",
            "Дивное",
            "Дивное",
            "Дивное",
            "Дигора",
            "Димитровград",
            "Динская",
            "Дмитриевка",
            "Дмитриев-Льговский",
            "Дмитров",
            "Дмитровск-Орловский",
            "Дно",
            "Добринка",
            "Доброволец",
            "Добровольск",
            "Доброе",
            "Добрянка",
            "Доваторовка",
            "Довольное",
            "Долгодеревенское",
            "Долгоруково",
            "Долгоруково",
            "Домбаровский",
            "Домново",
            "Домодедово",
            "Донецк",
            "Донской",
            "Дорогобуж",
            "Дорожное",
            "Дрожжаное",
            "Дружба",
            "Дубенки",
            "Дубна",
            "Дубна",
            "Дубовское",
            "Дубровка",
            "Дубровка",
            "Дудинка",
            "Дульдурга",
            "Думиничи",
            "Дунаевка",
            "Духовницкое",
            "Духовщина",
            "Дюртюли",
            "Дятьково",
            "Егорлыкская",
            "Егорьевск",
            "Ейск",
            "Екатеринбург",
            "Екатериновка",
            "Елабуга",
            "Елец",
            "Елизово",
            "Елово",
            "Еловое",
            "Ельники",
            "Ельники",
            "Ельня",
            "Ельняки",
            "Ельцовка",
            "Еманжелинск",
            "Емва",
            "Емельяново",
            "Енисейск",
            "Енотаевка",
            "Ермаково",
            "Ермаковское",
            "Ермекеево",
            "Ермишь",
            "Ермолаево",
            "Ершичи",
            "Ершов",
            "Ершово",
            "Ессентуки",
            "Еткуль",
            "Ефремов",
            "Жаворонково",
            "Железноводск",
            "Железногорск",
            "Железногорск",
            "Железногорск-Илимский",
            "Железнодорожный",
            "Желудево",
            "Жердевка",
            "Жигулевск",
            "Жиздра",
            "Жилино",
            "Жиратино",
            "Жуковка",
            "Жуково",
            "Жуковский",
            "Журавлевка",
            "Забайкальск",
            "Забарье",
            "Заветное",
            "Завитинск",
            "Заводоуковск",
            "Заволжье",
            "Завьялово",
            "Завьялово",
            "Загородный",
            "Загорское",
            "Задонск",
            "Заинск",
            "Зайцево",
            "Закаменск",
            "Залари",
            "Залегощь",
            "Залесово",
            "Залесье",
            "Заливино",
            "Заливное",
            "Залукокоаже",
            "Заовражное",
            "Заозерный",
            "Заозерск",
            "Заозерье",
            "Заокский",
            "Заостровье",
            "Западная Двина",
            "Западный",
            "Заповедное",
            "Заполярный",
            "Зарайск",
            "Заречное",
            "Заречный",
            "Заречье",
            "Заречье",
            "Заринск",
            "Звездный",
            "Звенигово",
            "Звенигород",
            "Звеньевое",
            "Зверево",
            "Звериноголовское",
            "Здвинск",
            "Зеленогорск",
            "Зеленоградск",
            "Зеленодольск",
            "Зеленое",
            "Зеленокумск",
            "Зеленчукская",
            "Земетчино",
            "Зерноград",
            "Зея",
            "Зилаир",
            "Зима",
            "Зимовники",
            "Златоуст",
            "Злынка",
            "Змеиногорск",
            "Змиевка",
            "Знаменка",
            "Знаменка",
            "Знаменск",
            "Знаменск",
            "Знаменское",
            "Знаменское",
            "Знаменское",
            "Золотухино",
            "Зональное",
            "Зорино",
            "Зубова Поляна",
            "Зубцов",
            "Зуевка",
            "Зырянское",
            "Ибреси",
            "Ивановка",
            "Иваново",
            "Ивантеевка",
            "Ивдель",
            "Ивня",
            "Иволгинск",
            "Иглино",
            "Игра",
            "Идринское",
            "Ижевск",
            "Ижма",
            "Ижморский",
            "Извилино",
            "Измалково",
            "Изобильное",
            "Изобильный",
            "Ики-Бурул",
            "Икряное",
            "Иланский",
            "Илек",
            "Ильинский",
            "Ильинское-Хованское",
            "Ильинско-Подомское",
            "Ильичевка",
            "Ильичевка",
            "Илюшино",
            "Инжавино",
            "Инза",
            "Инсар",
            "Инта",
            "Ипатово",
            "Ирбейское",
            "Ирбит",
            "Иркутск",
            "Исаклы",
            "Исаково",
            "Исетское",
            "Исилькуль",
            "Искитим",
            "Исса",
            "Истра",
            "Истровка",
            "Исянгулово",
            "Ишеевка",
            "Ишим",
            "Ишимбай",
            "Йошкар-ола",
            "Кавалерово",
            "Кавказская",
            "Кагальницкая",
            "Кадом",
            "Кадошкино",
            "Кадуй",
            "Кадый",
            "Казанское",
            "Казань",
            "Казачинское",
            "Казачинское",
            "Кайбицы",
            "Калач",
            "Калачинск",
            "Калга",
            "Калевала",
            "Калининград",
            "Калинино",
            "Калининск",
            "Калининская",
            "Калининское",
            "Калинково",
            "Калиновка",
            "Калманка",
            "Калтасы",
            "Калуга",
            "Калужское",
            "Калязин",
            "Камбарка",
            "Каменка",
            "Каменка",
            "Каменка",
            "Каменоломни",
            "Каменск- Шахтинский",
            "Каменское",
            "Каменское",
            "Каменск-Уральский",
            "Камень-на-Оби",
            "Камень-Рыболов",
            "Камешково",
            "Камское Устье",
            "Камызяк",
            "Камышлов",
            "Канаш",
            "Канаш",
            "Кандалакша",
            "Каневская",
            "Канск",
            "Кантемировка",
            "Кара",
            "Карабаш",
            "Караблино",
            "Карагай",
            "Караидель",
            "Каракулино",
            "Карамышево",
            "Карасук",
            "Каратузское",
            "Карачев",
            "Каргаполье",
            "Каргасок",
            "Каргат",
            "Каргополь",
            "Кардымово",
            "Кармаскалы",
            "Карпинск",
            "Карпогоры",
            "Карсун",
            "Карталы",
            "Карымская",
            "Касимов",
            "Касли",
            "Каспийский",
            "Касторное",
            "Касумкент",
            "Катав-Ивановск",
            "Катайск",
            "Качканар",
            "Кашары",
            "Кашин",
            "Каширское",
            "Каштановка",
            "Каштаново",
            "Каштаново",
            "Кваркено",
            "Кедровый",
            "Кез",
            "Кемерово",
            "Кемля",
            "Кемь",
            "Кетово",
            "Кетченеры",
            "Кижинга",
            "Кизел",
            "Кизильское",
            "Кизляр",
            "Кизнер",
            "Кикнур",
            "Килемары",
            "Кильмезь",
            "Кимовск",
            "Кимры",
            "Кингесепп",
            "Кинель",
            "Кинель-Черкасы",
            "Кинешма",
            "Киргиз-Мияки",
            "Киреевск",
            "Киренск",
            "Киржач",
            "Кириллов",
            "Кириши",
            "Киров",
            "Киров",
            "Кирова",
            "Кировград",
            "Кирово-Чепецк",
            "Кировск",
            "Кировск",
            "Кировский",
            "Кирс",
            "Кирсанов",
            "Киселевск",
            "Кисловодск",
            "Кичменгский Городок",
            "Киясово",
            "Кленовое",
            "Клетня",
            "Климовка",
            "Климово",
            "Клин",
            "Клинцы",
            "Ключи",
            "Ключи",
            "Клявлино",
            "Княгинино",
            "Ковдор",
            "Ковернино",
            "Ковров",
            "Коврово",
            "Ковылкино",
            "Когалым",
            "Кодинск",
            "Кожевниково",
            "Козельск",
            "Козловка",
            "Козулька",
            "Козьмодемьянск",
            "Койгородок",
            "Кола",
            "Кологрив",
            "Коломна",
            "Колосовка",
            "Колосовка",
            "Колпашево",
            "Колпна",
            "Колывань",
            "Колышлей",
            "Кольчугино",
            "Комаричи",
            "Комсомольск",
            "Комсомольск",
            "Комсомольский",
            "Комсомольск-на-Амуре",
            "Комсомольское",
            "Конаково",
            "Кондинское",
            "Кондоль",
            "Кондопога",
            "Кондрово",
            "Коноша",
            "Константиновка",
            "Константиновка",
            "Константиновск",
            "Конышевка",
            "Копейск",
            "Копьево",
            "Коренево",
            "Кореновск",
            "Коркино",
            "Кормиловка",
            "Корнево",
            "Короленково",
            "Короча",
            "Корткерос",
            "Корф",
            "Коряжма",
            "Косиха",
            "Костомукша",
            "Кострово",
            "Кострома",
            "Костромино",
            "Костюковка",
            "Котельнич",
            "Котлас",
            "Котовск",
            "Коченево",
            "Кочки",
            "Кочкурово",
            "Кош-Агач",
            "Кошехабль",
            "Кошки",
            "Кошхатау",
            "Крапивинский",
            "Красная Горбатка",
            "Красная Горка",
            "Красная Горка",
            "Красноармейск",
            "Красноармейская",
            "Красноармейское",
            "Красноармейское",
            "Красноборск",
            "Красновишерск",
            "Красногвардейск",
            "Красногвардейское",
            "Красногвардейское",
            "Красногородское",
            "Красногорское",
            "Красногорское",
            "Красногорское",
            "Краснодар",
            "Красное",
            "Красное",
            "Красное",
            "Красное-на-Волге",
            "Краснозерское",
            "Краснознаменск",
            "Красной Чикой",
            "Краснокаменск",
            "Краснокамск",
            "Краснолесье",
            "Красноолмский",
            "Краснополье",
            "Краснополянское",
            "Краснослободск",
            "Красноторовка",
            "Краснотуранск",
            "Краснотурьинск",
            "Красноуральск",
            "Красноусольский",
            "Красноуфимск",
            "Краснофлотское",
            "Краснощеково",
            "Красноярск",
            "Красноярское",
            "Красные Баки",
            "Красные Четаи",
            "Красный",
            "Красный бор",
            "Красный Бор",
            "Красный Кут",
            "Красный Сулин",
            "Красный Холм",
            "Красный Яр",
            "Красный Яр",
            "Красный Яр",
            "Крестцы",
            "Кривошеино",
            "Кромы",
            "Кромы",
            "Кропоткин",
            "Кругловка",
            "Крутинка",
            "Крутиха",
            "Крылово",
            "Крыловская",
            "Крымск",
            "Кстово",
            "Кубановка",
            "Кувандык",
            "Кувшиново",
            "Кугеси",
            "Кудепста",
            "Кудымкар",
            "Куеда",
            "Куженер",
            "Кузнецк",
            "Кузоватово",
            "Куйбышев",
            "Куйбышево",
            "Куйбышевское",
            "Кукмор",
            "Кулебаки",
            "Кулунда",
            "Кумачово",
            "Кумены",
            "Кумертау",
            "Кунашак",
            "Кунгур",
            "Кунья",
            "Купино",
            "Курагино",
            "Курах",
            "Курган",
            "Курганинск",
            "Куркино",
            "Курманаевка",
            "Курортное",
            "Курсавка",
            "Курск",
            "Куртамыш",
            "Курумкан",
            "Курчатов",
            "Курья",
            "Куса",
            "Кушва",
            "Кушнаренково",
            "Кущевская",
            "Кшенский",
            "Кызыл",
            "Кытманово",
            "Кыштовка",
            "Кыштым",
            "Кяхта",
            "Лабинск",
            "Ладушкин",
            "Лазо",
            "Лаишево",
            "Лангепас",
            "Лахденпохья",
            "Лебедянь",
            "Лебяжье",
            "Лебяжье",
            "Лев Толстой",
            "Левобережное",
            "Левокумское",
            "Лежнево",
            "Ленинградская",
            "Лениногорск",
            "Ленинский",
            "Ленинск-Кузнецкий",
            "Ленинское",
            "Ленск",
            "Лермонтов",
            "Лермонтово",
            "Лесное",
            "Лесное",
            "Лесное",
            "Лесное",
            "Лесозаводск",
            "Лесосибирск",
            "Летняя Ставка",
            "Лешуконское",
            "Ливны",
            "Лиман",
            "Линево",
            "Липецк",
            "Липин Бор",
            "Липняки",
            "Липовка",
            "Липово",
            "Лиски",
            "Лихославль",
            "Ловозеро",
            "Лодейное Поле",
            "Локня",
            "Локоть",
            "Ломово",
            "Ломоносов",
            "Ломоносовка",
            "Лоо",
            "Лопатино",
            "Лотошино",
            "Лоухи",
            "Луга",
            "Луговое",
            "Луговое",
            "Луговое",
            "Луговское",
            "Лужки",
            "Луза",
            "Лукоянов",
            "Лунино",
            "Лунино",
            "Лунино",
            "Луховицы",
            "Лучегорск",
            "Лысково",
            "Лысые Горы",
            "Лысьва",
            "Львовское",
            "Льгов",
            "Любим",
            "Любинский",
            "Любытино",
            "Людиново",
            "Лямбирь",
            "Лянтор",
            "Магадан",
            "Магнитогорск",
            "Маевка",
            "Майкоп",
            "Майма",
            "Майна",
            "Майский",
            "Майское",
            "Майское",
            "Майя",
            "Макаров",
            "Макарьев",
            "Максатиха",
            "Макушино",
            "Малая Вишера",
            "Малая Пурга",
            "Малая Сердоба",
            "Малгобек",
            "Малиники",
            "Малиновка",
            "Малиновка",
            "Малмыж",
            "Малоархангельское",
            "Маломожайское",
            "Малояз",
            "Малоярославец",
            "Малые Горки",
            "Мальцево",
            "Мамадыш",
            "Мамоново",
            "Мамонтово",
            "Мантурово",
            "Мантурово",
            "Марево",
            "Мариинск",
            "Мариинский Посад",
            "Маркс",
            "Мартыновка",
            "Маршальское",
            "Марьино",
            "Марьяновка",
            "Маслянино",
            "Матвеев Курган",
            "Матвеевка",
            "Матросово",
            "Махачкала",
            "Маяковское",
            "Мглин",
            "Мегион",
            "Медвежьегорск",
            "Медвенка",
            "Медногорск",
            "Медовое",
            "Медынь",
            "Междуреченск",
            "Междуреченский",
            "Междуреченский",
            "Междуречье",
            "Мезень",
            "Меленки",
            "Мелеуз",
            "Мельниково",
            "Мельниково",
            "Менделеево",
            "Менделеевск",
            "Мензелинск",
            "Месягутово",
            "Мещовск",
            "Миайлово",
            "Миасс",
            "Миасское",
            "Миллерово",
            "Милославское",
            "Мильково",
            "Милютинская",
            "Минеральные Воды",
            "Минусинск",
            "Миньяр",
            "Мирный",
            "Мирный",
            "Михайлов",
            "Михайловка",
            "Михайловка",
            "Мичуринск",
            "Мичуринский",
            "Мишкино",
            "Мишкино",
            "Могайтуй",
            "Можайск",
            "Можга",
            "Моздок",
            "Мозырь",
            "Мокроус",
            "Мокроусово",
            "Мокшан",
            "Молчаново",
            "Монастырщина",
            "Мончегорск",
            "Моргауши",
            "Моргуново",
            "Мордово",
            "Мордовское",
            "Морки",
            "Морозовск",
            "Моршанск",
            "Мосальск",
            "Москаленки",
            "Москва",
            "Мостовской",
            "Мошенское",
            "Мошково",
            "Мраково",
            "Муезерский",
            "Муравленко",
            "Мураши",
            "Мурманск",
            "Муром",
            "Муромское",
            "Муромцево",
            "Муслюмово",
            "Мухоршибирь",
            "Мучкапский",
            "Мценск",
            "Мыски",
            "Мысовка",
            "Мышкин",
            "Набережные Челны",
            "Навашино",
            "Навля",
            "Нагорное",
            "Нагорск",
            "Надеждино",
            "Назарово",
            "Назрань",
            "Называевск",
            "Наимово",
            "Нальчик",
            "Намцы",
            "Нариманов",
            "Наровчат",
            "Наро-Фоминск",
            "Нарткала",
            "Нарышкино",
            "Нарьян-Мар",
            "Находка",
            "Началово",
            "Невель",
            "Неверкино",
            "Невинномысск",
            "Невское",
            "Невьянск",
            "Некрасово",
            "Некрасово",
            "Некрасовское",
            "Нелидово",
            "Нема",
            "Неман",
            "Неманское",
            "Нерехта",
            "Нерчинск",
            "Нерюнгри",
            "Нестеров",
            "Нефтегорск",
            "Нефтекамск",
            "Нефтекумск",
            "Нефтеюганск",
            "Нея",
            "Нива",
            "Нивенское",
            "Нижневартовск",
            "Нижнедевицк",
            "Нижнекамск",
            "Нижние Серги",
            "Нижний Ингаш",
            "Нижний Ломов",
            "Нижний Новгород",
            "Нижний Тагил",
            "Нижняя Омка",
            "Нижняя Салда",
            "Нижняя Тавда",
            "Нижняя Тура",
            "Низовье",
            "Никель",
            "Николаевка",
            "Николаевск-на-Амуре",
            "Николо-Березовка",
            "Никольск",
            "Никольск",
            "Нилово",
            "Новая деревня",
            "Новая Ляля",
            "Новая Малыкла",
            "Новая Усмань",
            "Новичиха",
            "Новоалександровск",
            "Новоалтайск",
            "Новобелокатай",
            "Новобирилюссы",
            "Новобобруйск",
            "Нововаршавка",
            "Нововоронеж",
            "Новогурьевское",
            "Новодвинск",
            "Новодугино",
            "Новоегорьевское",
            "Новозыбков",
            "Новокиевский Увал",
            "Новоколозное",
            "Новокубанск",
            "Новокузнецк",
            "Новокуйбышевск",
            "Новомичуринск",
            "Новомосковск",
            "Новомосковский",
            "Новомосковское",
            "Новонукутский",
            "Новоорск",
            "Новопавловск",
            "Новопокровская",
            "Новоржев",
            "Новороссийск",
            "Новоселицкое",
            "Новоселово",
            "Новоселово",
            "Новосергиевка",
            "Новосибирск",
            "Новосокольники",
            "Новоспасское",
            "Новостроево",
            "Новостроево",
            "Новостройка",
            "Новотроицк",
            "Новоузенск",
            "Новоульяновск",
            "Новоуральск",
            "Новохоперск",
            "Новочеркасск",
            "Новошахтинск",
            "Новошешминск",
            "Новые Бурасы",
            "Новый Некоуз",
            "Новый Оскол",
            "Новый Торъял",
            "Ногинск",
            "Ножай-Юрт",
            "Нолинск",
            "Норильск",
            "Ноябрьск",
            "Нурлаты",
            "Нытва",
            "Нюксеница",
            "Нюрба",
            "Нягань",
            "Нязепетровск",
            "Няндома",
            "о.Соловки",
            "Обливская",
            "Обнинск",
            "Обоянь",
            "Обь",
            "Обьячево",
            "Овражье",
            "Одесское",
            "Одоев",
            "Озерки",
            "Озерки",
            "Озерск",
            "Озерск",
            "Озеры",
            "Озинки",
            "Оконешниково",
            "Октябрьск",
            "Октябрьск",
            "Октябрьский",
            "Октябрьский",
            "Октябрьский",
            "Октябрьское",
            "Октябрьское",
            "Октябрьское",
            "Октябрьское",
            "Окуловка",
            "Олекминск",
            "Оленегорск",
            "Оленино",
            "Олеово",
            "Олонец",
            "Ольга",
            "Ольоватка",
            "Ольовка",
            "Ольховатка",
            "Омск",
            "Омсукчан",
            "Омутинский",
            "Омутнинск",
            "Онгудай",
            "Онега",
            "Оотное",
            "Опарино",
            "Опочка",
            "Орда",
            "Ордынское",
            "Орел",
            "Оренбург",
            "Ореовка",
            "Орехово-Зуево",
            "Оричи",
            "Орлов",
            "Орловка",
            "Орловский",
            "Орск",
            "Оршанка",
            "Оса",
            "Осинники",
            "Осиновка",
            "Оссора",
            "Осташков",
            "Остров",
            "Островское",
            "Островское",
            "Острогожск",
            "Острогожское",
            "Отрадная",
            "Отрадное",
            "Отрадный",
            "Оханск",
            "Охотск",
            "Очер",
            "Павино",
            "Павловка",
            "Павлово",
            "Павловск",
            "Павловск",
            "Павловская",
            "Павловский Посад",
            "Павлоградка",
            "Палана",
            "Палатка",
            "Палех",
            "Палкино",
            "Панино",
            "Панкрушиха",
            "Парабель",
            "Параньга",
            "Партизанск",
            "Партизанское",
            "Партизанское",
            "Парфеньево",
            "Парфино",
            "Пахачи",
            "Пачелма",
            "Пенза",
            "Пено",
            "Пеньки",
            "Первомайск",
            "Первомайский",
            "Первомайский",
            "Первомайский",
            "Первомайское",
            "Первомайское",
            "Первомайское",
            "Первоуральск",
            "Перевоз",
            "Переволоцкий",
            "Перелюб",
            "Перемышль",
            "Переславское",
            "Переяславка",
            "Переяславль-Залесский",
            "Пермь",
            "Песочное",
            "Пестово",
            "Пестрецы",
            "Пестровка",
            "Пестяки",
            "Песчанокопск",
            "Петино",
            "Петрово",
            "Петровск",
            "Петровское",
            "Петрозаводск",
            "Петропавловка",
            "Петропавловка",
            "Петропавловск-Камчатский",
            "Петропавловское",
            "Петухово",
            "Петушки",
            "Печора",
            "Печоры",
            "Пижанка",
            "Пикалево",
            "Пильна",
            "Пионерский",
            "Пировское",
            "Пителино",
            "Питерка",
            "Питкяранта",
            "Пичаево",
            "Плавск",
            "Пласт",
            "Плесецк",
            "Плешаново",
            "Плюсса",
            "Победино",
            "Поваровка",
            "Поворино",
            "Погар",
            "Пограничный",
            "Пограничный",
            "Подгоренский",
            "Подгорное",
            "Подгорное",
            "Подгоровка",
            "Поддорье",
            "Поддубное",
            "Поддубное",
            "Поддубы",
            "Поддубье",
            "Подлипово",
            "Подольск",
            "Подосиновец",
            "Подпорожье",
            "Покровка",
            "Покровск",
            "Покровское",
            "Покровское",
            "Покровское",
            "Покровское",
            "Покрышкино",
            "Полевский",
            "Полесск",
            "Полина Осипенко",
            "Половинное",
            "Полтавка",
            "Полтавское",
            "Полярные Зори",
            "Полярный",
            "Поназырево",
            "Пономаревка",
            "Поныри",
            "Порецкое",
            "Поречье",
            "Порхов",
            "Поспелиха",
            "Похвистнево",
            "Почеп",
            "Починки",
            "Починок",
            "Пошехонье",
            "Правдино",
            "Правдинск",
            "Преградная",
            "Пречистое",
            "Приаргунск",
            "Прибрежное",
            "Приволжск",
            "Приволжье",
            "Привольное",
            "Пригородное",
            "Пригородное",
            "Придорожное",
            "Придорожное",
            "Приморск",
            "Приморско-Ахтарск",
            "Приморье",
            "Приморье",
            "Приозерное",
            "Приозерное",
            "Приозерск",
            "Пристень",
            "Приютное",
            "Прокопьевск",
            "Проладное",
            "Пролетарск",
            "Промышленная",
            "Пронск",
            "Прооровка",
            "Прохладный",
            "Прохоровка",
            "Прудное",
            "Пруды",
            "Пряжа",
            "Прямицыно",
            "Псков",
            "Пугачев",
            "Пудож",
            "Пустошка",
            "Путятино",
            "Пучеж",
            "Пушкино",
            "Пушкинские Горы",
            "Пыталово",
            "Пыть-ях",
            "Пышма",
            "Пыщуг",
            "Пятигорск",
            "Пятидорожное",
            "Радищево",
            "Радужный",
            "Радужный",
            "Раевский",
            "Разино",
            "Райчихинск",
            "Ракитино",
            "Ракитное",
            "Раменское",
            "Рамешки",
            "Рамонь",
            "Рассвет",
            "Рассказово",
            "Ребриха",
            "Ревда",
            "Реж",
            "Ремонтное",
            "Репьевка",
            "Ржакса",
            "Ржев",
            "Ржевское",
            "Ровеньки",
            "Ровное",
            "Ровное",
            "Рогнедино",
            "Родино",
            "Родионово-Несветайская",
            "Родники",
            "Родники",
            "Романовка",
            "Романово",
            "Романово",
            "Романовская",
            "Ромоданово",
            "Рославль",
            "Россия",
            "Россошь",
            "Ростов",
            "Ростов",
            "Рощино",
            "Рощино",
            "Ртищево",
            "Рубцовск",
            "Рудня",
            "Руза",
            "Рузаевка",
            "Русская Поляна",
            "Русский Камешкир",
            "Ручьи",
            "Рыбачий",
            "Рыбинск",
            "Рыбинск",
            "Рыбкино",
            "Рыбная Слобода",
            "Рыбное",
            "Рыльск",
            "Рябиновка",
            "Ряжск",
            "Рязань",
            "Савино",
            "Садовое",
            "Садовое",
            "Садовое",
            "Сакмара",
            "Салават",
            "Сальск",
            "Самара",
            "Самойловка",
            "Сангар",
            "Сандово",
            "Санкт-Петербург",
            "Санчурск",
            "Сапожок",
            "Саракташ",
            "Саранск",
            "Саранское",
            "Сарапул",
            "Саратов",
            "Саргатское",
            "Сарманово",
            "Саров",
            "Сасово",
            "Сатинка",
            "Сатка",
            "Сафакулево",
            "Сафоново",
            "Саяногорск",
            "Светлогорск",
            "Светлоград",
            "Светлый",
            "Светлый",
            "Свеча",
            "Свобода",
            "Свободный",
            "Себеж",
            "Северное",
            "Северное",
            "Северный",
            "Северный",
            "Северобайкальск",
            "Северодвинск",
            "Североморск",
            "Североуральск",
            "Северск",
            "Северская",
            "Севск",
            "Севское",
            "Сегежа",
            "Седельниково",
            "Сеймчан",
            "Село Им. Бабушкина",
            "Селты",
            "Семенов",
            "Семеново",
            "Семикаракорск",
            "Семилуки",
            "Сенгилей",
            "Сергач",
            "Сергиев Посад",
            "Сергиевск",
            "Сердобск",
            "Серебрянные Пруды",
            "Сернур",
            "Серов",
            "Серпухов",
            "Серышево",
            "Сеченово",
            "Сибай",
            "Сива",
            "Скалистый",
            "Сковородино",
            "Скопин",
            "Славгород",
            "Славинск",
            "Славск",
            "Славское",
            "Славянка",
            "Славяновка",
            "Славянск-на-Кубани",
            "Славянское",
            "Сладково",
            "Сланцы",
            "Слободской",
            "Смоленск",
            "Смоленское",
            "Снежинск",
            "Снежногрск",
            "Собинка",
            "Соболево",
            "Советск",
            "Советск",
            "Советская Гавань",
            "Советский",
            "Советский",
            "Советское",
            "Советское",
            "Совозное",
            "Совозный",
            "Сокол",
            "Сокольники",
            "Солдатово",
            "Солдатово",
            "Солигалич",
            "Соликамск",
            "Солнечная Долина",
            "Солнечногорск",
            "Солнечный",
            "Солнцево",
            "Соловьево",
            "Солонешное",
            "Солонцы",
            "Солотча",
            "Солтон",
            "Соль-Илецк",
            "Сольцы",
            "Сонково",
            "Сопкино",
            "Сорочинск",
            "Сорск",
            "Сортавала",
            "Сосновка",
            "Сосновка",
            "Сосновка",
            "Сосновка",
            "Сосновоборск",
            "Сосновоборск",
            "Сосново-Озерское",
            "Сосновское",
            "Сосновый Бор",
            "Сосногорск",
            "Сочи",
            "Спас-Деменск",
            "Спас-Клепики",
            "Спасск",
            "Спасск-Дальний",
            "Спасское",
            "Спасск-Рязанский",
            "Средние Пахачи",
            "Сретенск",
            "Ставрополь",
            "Становое",
            "Старая Кулатка",
            "Старая Майна",
            "Старая Русса",
            "Старая Чара",
            "Старица",
            "Староалейское",
            "Стародуб",
            "Старое Шайгово",
            "Старожилово",
            "Староминская",
            "Старощербиновская",
            "Староюрьево",
            "Старый Оскол",
            "Степное",
            "Степное",
            "Стерлибашево",
            "Стерлитамак",
            "Стрежевой",
            "Строитель",
            "Стройный",
            "Струги- Красные",
            "Ступино",
            "Суворов",
            "Суворовка",
            "Суворово",
            "Суджа",
            "Судиславль",
            "Судогда",
            "Суздаль",
            "Суземка",
            "Сузун",
            "Суксун",
            "Суна",
            "Сунтар",
            "Суоярви",
            "Сураж",
            "Сургут",
            "Сурское",
            "Сусанино",
            "Сусуман",
            "Сухиничи",
            "Сухобузимское",
            "Сухой Лог",
            "Сызрань",
            "Сыктывкар",
            "Сысерть",
            "Сычевка",
            "Сюмси",
            "Сямжа",
            "Таборы",
            "Табуны",
            "Тавда",
            "Таврическое",
            "Таганрог",
            "Таилтып",
            "Тайга",
            "Тайшет",
            "Талдом",
            "Талица",
            "Таловая",
            "Талпаки",
            "Тальменка",
            "Тамала",
            "Тамбов",
            "Тара",
            "Тарасовский",
            "Тарбагатай",
            "Тарко-сале",
            "Тарногский Городок",
            "Таруса",
            "Тасеево",
            "Татарск",
            "Татищево",
            "Тахтамукай",
            "Тацинский",
            "Ташла",
            "Таштагол",
            "Таштып",
            "Тбилисская",
            "Тверь",
            "Тевриз",
            "Тегульдет",
            "Тейково",
            "Темкино",
            "Темников",
            "Темрюк",
            "Теньгушево",
            "Теплое",
            "Тербуны",
            "Терек",
            "Тереньга",
            "Терней",
            "Терновка",
            "Терскол",
            "Тетюши",
            "Тигиль",
            "Тикси",
            "Тиличики",
            "Тим",
            "Тимашевск",
            "Тимирязево",
            "Тимофеевка",
            "Тимофеево",
            "Тисуль",
            "Тихвин",
            "Тихорецк",
            "Тишино",
            "Тобольск",
            "Тогул",
            "Тогучин",
            "Токаревка",
            "Толбазы",
            "Тольятти",
            "Томск",
            "Тонкино",
            "Топки",
            "Топчиха",
            "Торбеево",
            "Торжок",
            "Торопец",
            "Тосно",
            "Тотьма",
            "Тоцкое",
            "Трехгорный",
            "Троицк",
            "Троицк",
            "Троицкое",
            "Троицкое",
            "Троицкое",
            "Троицко-Печорск",
            "Тросна",
            "Тростники",
            "Трубачевск",
            "Туапсе",
            "Тугаев",
            "Тугулым",
            "Тужа",
            "Туймазы",
            "Тула",
            "Тульский",
            "Тумановка",
            "Тургенево",
            "Туринск",
            "Туринская Слобода",
            "Турки",
            "Турочак",
            "Турунтаево",
            "Тында",
            "Тырныауз",
            "Тюкалинск",
            "Тюленино",
            "Тюльган",
            "Тюлячи",
            "Тюменцево",
            "Тюмень",
            "Тюхтет",
            "Тяжинский",
            "Убинское",
            "Ува",
            "Уварово",
            "Уват",
            "Увельский",
            "Углич",
            "Угловское",
            "Угра",
            "Удомля",
            "Ужур",
            "Узловая",
            "Узловое",
            "Уинское",
            "Уйское",
            "Улан-Удэ",
            "Улеты",
            "Ульяново",
            "Ульяново",
            "Ульяновск",
            "Умба",
            "Умет",
            "Унеча",
            "Уни",
            "Упорово",
            "Уразовка",
            "Урай",
            "Урень",
            "Уржум",
            "Урмары",
            "Урус-Мартан",
            "Уруссу",
            "Усвяты",
            "Усинск",
            "Усмань",
            "Усогорск",
            "Усолье",
            "Усолье-Сибирское",
            "Успенское",
            "Уссурийск",
            "Усть-Абакан",
            "Усть-Большерецк",
            "Усть-Джегута",
            "Усть-Донецкий",
            "Устье",
            "Усть-Илимск",
            "Усть-Ишим",
            "Усть-Калманка",
            "Усть-Камчатск",
            "Усть-Кан",
            "Усть-Катав",
            "Усть-Кишерть",
            "Усть-Кулом",
            "Усть-Кут",
            "Усть-Лабинск",
            "Усть-Мая",
            "Усть-Омчуг",
            "Усть-Пристань",
            "Усть-Тарка",
            "Усть-Уда",
            "Усть-Хайрюзово",
            "Усть-Цильма",
            "Устюжна",
            "Уфа",
            "Ухолово",
            "Ухта",
            "Учалы",
            "Учкекен",
            "Ушаковка",
            "Ушаково",
            "Уяр",
            "Фаленки",
            "Фатеж",
            "Февральское",
            "Федоровка",
            "Федотово",
            "Ферзиково",
            "Фершампенуаз",
            "Филипповка",
            "Фирово",
            "Фокино",
            "Фрунзенское",
            "Фурманов",
            "Фурмановка",
            "Фурманово",
            "Хабаровск",
            "Хабары",
            "Хакуринохабль",
            "Хандыга",
            "Ханты-мансийск",
            "Харабали",
            "Харовск",
            "Хвалынск",
            "Хвастовичи",
            "Хвойная",
            "Хилок",
            "Хиславичи",
            "Хлебниково",
            "Хлевное",
            "Холм",
            "Холм-Жирковский",
            "Холмогоровка",
            "Холмогоры",
            "Холмогорье",
            "Холмы",
            "Хомутивка",
            "Хоринск",
            "Хороль",
            "Хоста",
            "Хохольский",
            "Цаган Аман",
            "Целина",
            "Целинное",
            "Целинное",
            "Цивильск",
            "Цимлянск",
            "Чагода",
            "Чайкино",
            "Чайковский",
            "Чалтырь",
            "Чамзинка",
            "Чаны",
            "Чапаевск",
            "Чаплыгин",
            "Чарышское",
            "Частоозерье",
            "Частые",
            "Чебаркуль",
            "Чебоксары",
            "Чегдомын",
            "Чегем Первый",
            "Чекмагуш",
            "Челно-Вершины",
            "Челябинск",
            "Чеово",
            "Чердаклы",
            "Чердынь",
            "Черемисиново",
            "Черемуино",
            "Черемхово",
            "Черемшаны",
            "Черепаново",
            "Череповец",
            "Черкесск",
            "Черлак",
            "Черниговка",
            "Черноголовка",
            "Черногорск",
            "Чернушка",
            "Черный Яр",
            "Чернышевск",
            "Чернышевское",
            "Чернь",
            "Чернянка",
            "Черняховск",
            "Чертково",
            "Чесма",
            "Чехов",
            "Чикола",
            "Чистоозерное",
            "Чистополь",
            "Чистополье",
            "Чистые пруды",
            "Чита",
            "Чишмы",
            "Чкаловск",
            "Чоя",
            "Чугуевка",
            "Чудово",
            "Чулым",
            "Чумикан",
            "Чунский",
            "Чурапча",
            "Чусовой",
            "Чухлома",
            "Чучково",
            "Шадринск",
            "Шали",
            "Шалинское",
            "Шаля",
            "Шаран",
            "Шаранга",
            "Шаркан",
            "Шарлык",
            "Шарыпово",
            "Шарья",
            "Шатки",
            "Шатой",
            "Шатрово",
            "Шатура",
            "Шаховская",
            "Шахты",
            "Шахунья",
            "Шацк",
            "Шебалино",
            "Шебекино",
            "Шевченко",
            "Шексна",
            "Шелаболиха",
            "Шелехов",
            "Шелопугино",
            "Шемурша",
            "Шемышейка",
            "Шенкурск",
            "Шентала",
            "Шербакуль",
            "Шилка",
            "Шилово",
            "Шимановск",
            "Шимск",
            "Шипуново",
            "Шира",
            "Широкое",
            "Шовгеновский",
            "Шолоово",
            "Шоссейный",
            "Шуйское",
            "Шумерля",
            "Шумиха",
            "Шумячи",
            "Шушенское",
            "Шуя",
            "Щегловка",
            "Щеглы",
            "Щекино",
            "Щелково",
            "Щигры",
            "Щучье",
            "Ытык-Кюель",
            "Электросталь",
            "Элиста",
            "Эльхотово",
            "Энгельс",
            "Эртиль",
            "Эссо",
            "Юдино",
            "Южа",
            "Южно-Сахалинск",
            "Южноуральск",
            "Южный",
            "Юкаменское",
            "Юрга",
            "Юргамыш",
            "Юргинское",
            "Юрино",
            "Юрьев- Польский",
            "Юрьевич",
            "Юрья",
            "Юхнов",
            "Яблоневка",
            "Яблоневка",
            "Яблоновка",
            "Явас",
            "Ягодное",
            "Ядрин",
            "Языково",
            "Яковлевка",
            "Якутск",
            "Якшур-бодья",
            "Ялуторовск",
            "Яльчики",
            "Янаул",
            "Янтарный",
            "Янтиково",
            "Яр",
            "Яранск",
            "Яренск",
            "Ярки",
            "Ярково",
            "Яровое",
            "Ярославль",
            "Ярославское",
            "Ярцево",
            "Ясеньское",
            "Ясная поляна",
            "Ясногорск",
            "Ясное",
            "Ясный",
            "Яшалта",
            "Яшкино",
            "Яшкуль",
            "Яя"
        );
    }


}