<?php
/**
 * Установка модуля
 *
 * @package    Diafan.CMS
 * @author     diafan.ru
 * @version    5.4
 * @license    http://cms.diafan.ru/license.html
 * @copyright  Copyright (c) 2003-2014 OOO «Диафан» (http://diafan.ru)
 */

if (!defined('DIAFAN')) {
    include dirname(dirname(dirname(__FILE__))) . '/includes/404.php';
}

class Ubrr_install extends Install
{
    /**
     * @var string название
     */
    public $title = "УБРиР: интеграция";

    /**
     * @var array таблицы в базе данных
     */
    public $tables = array(
        array(
            "name" => "ubrr_twpg_orders",
            "fields" => array(
                array(
                    "name" => "id",
                    "type" => "INT(11) UNSIGNED NOT NULL AUTO_INCREMENT",
                ),
                array(
                    "name" => "diafan_pay_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                ),
                array(
                    "name" => "diafan_order_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                ),
                array(
                    "name" => "twpg_order_id",
                    "type" => "INT(11) UNSIGNED NOT NULL DEFAULT '0'",
                ),
                array(
                    "name" => "twpg_session_id",
                    "type" => "VARCHAR(40) NOT NULL",
                ),

            ),
            "keys" => array(
                "PRIMARY KEY (id)",
            ),
        ),
    );

    /**
     * @var array записи в таблице {modules}
     */
    public $modules = array(
        array(
            "name" => "ubrr",
            "admin" => true,
            "site" => true,
        ),
    );

    /**
     * @var array настройки
     */
    public $config = array(
        array('name' => 'ubrr_client_id', 'value' => ''),
        array('name' => 'ubrr_certificate_pass', 'value' => ''),
        array('name' => 'ubrr_test', 'value' => ''),
        array('name' => 'ubrr_new_certificate_password', 'value' => ''),
        array('name' => 'ubrr_certificate_create_date', 'value' => ''),
        Array('name' => 'ubrr_certificate_request_receivers', 'value' => 'eqv@ubrr.ru, alyushina@ubrr.ru')
    );

    /**
     * @var array меню административной части
     */
    public $admin = array(
        array(
            "name" => "УБРиР: интеграция",
            "rewrite" => "ubrr",
            "group_id" => "4",
            "sort" => 5,
            "act" => true,
            "children" => array(
                array(
                    "name" => "Заказы оплаченные через УБРиР",
                    "rewrite" => "ubrr/orders",
                    "sort" => 10,
                    "act" => true,
                ),
                array(
                    "name" => "Сверка итогов",
                    "rewrite" => "ubrr/reconcile",
                    "sort" => 20,
                    "act" => true,
                ),
                array(
                    "name" => "Журнал операций",
                    "rewrite" => "ubrr/journal",
                    "sort" => 30,
                    "act" => true,
                ),
                array(
                    "name" => "Генерация сертификатов",
                    "rewrite" => "ubrr/certificate_generate",
                    "sort" => 40,
                    "act" => true,
                ),
                array(
                    "name" => "Загрузка .pem файла",
                    "rewrite" => "ubrr/certificate_upload",
                    "sort" => 50,
                    "act" => true,
                ),
                array(
                    "name" => "Лог",
                    "rewrite" => "ubrr/log",
                    "sort" => 60,
                    "act" => true,
                ),
                array(
                    "name" => "Настройки",
                    "rewrite" => "ubrr/config",
                ),
            )
        ),
    );


    //TODO: актуализировать автодобавление платежной системы!
    public $sql = Array(
        "payment" => array(
            array(
                "name" => array('УБРиР', 'UBRR'),
                "text" => array('Оплата при помощи банковских карт через УБРиР.', 'Thank you for your purchase! Use an instant payment for the order via UBRR.'),
                "payment" => 'ubrr',
                "module_name" => 'ubrr',
            ),
        )
    );

    private function dirUbrrPaymentInstall($ABS_PATH)
    {
        return $ABS_PATH . 'modules/ubrr/install/modules/payment/ubrr';
    }

    private function dirPaymentBackends($ABS_PATH)
    {
        return $ABS_PATH . 'modules/payment/backend/ubrr';
    }


    protected function action()
    {
        $source = $this->dirUbrrPaymentInstall(ABSOLUTE_PATH);
        $ubrrPaymentBackend = $this->dirPaymentBackends(ABSOLUTE_PATH);
        $this->CopyDirFiles($source, $ubrrPaymentBackend);

        //Нужно еще в БД зарегистрировать

        parent::action();
    }


    private static function CopyDirFiles($source, $destination)
    {
        if (!is_dir($source)) {
            return;
        }
        if (!is_dir($destination)) {
            mkdir($destination);
        }

        $files = scandir($source);
        foreach ($files as $file) {
            if ($file == '.' || $file == '..')
                continue;

            if (is_file($source . '/' . $file)) {
                copy($source . '/' . $file, $destination . '/' . $file);
            }
        }
    }

    private static function RemoveDir($destination)
    {
        if (is_dir($destination)) {

            $files = scandir($destination);
            foreach ($files as $file) {
                if ($file == '.' || $file == '..')
                    continue;

                if (is_file($destination . '/' . $file)) {
                    unlink($destination . '/' . $file);
                }
            }
            rmdir($destination);
        }
    }


    protected function uninstall_action()
    {
        $ubrrPaymentBackend = $this->dirPaymentBackends(ABSOLUTE_PATH);
        $this->RemoveDir($ubrrPaymentBackend);

        //Нужно убратся за собой в БД

        parent::uninstall_action();
    }
}